summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--docs/reference/telepathy-glib/tp-svc.xml8
-rw-r--r--examples/cm/call/call-channel.c6
-rw-r--r--examples/cm/contactlist/conn.c8
-rw-r--r--examples/cm/echo-message-parts/chan.c4
-rw-r--r--examples/cm/extended/conn.c6
-rw-r--r--telepathy-glib/add-dispatch-operation-context-internal.h2
-rw-r--r--telepathy-glib/add-dispatch-operation-context.c12
-rw-r--r--telepathy-glib/base-call-channel.c26
-rw-r--r--telepathy-glib/base-call-content.c22
-rw-r--r--telepathy-glib/base-call-stream.c8
-rw-r--r--telepathy-glib/base-channel.c2
-rw-r--r--telepathy-glib/base-client.c10
-rw-r--r--telepathy-glib/base-connection-manager.c4
-rw-r--r--telepathy-glib/base-connection.c48
-rw-r--r--telepathy-glib/base-connection.h2
-rw-r--r--telepathy-glib/base-contact-list.c62
-rw-r--r--telepathy-glib/base-media-call-channel.c4
-rw-r--r--telepathy-glib/base-media-call-content.c22
-rw-r--r--telepathy-glib/base-media-call-stream.c26
-rw-r--r--telepathy-glib/base-password-channel.c12
-rw-r--r--telepathy-glib/base-protocol.c16
-rw-r--r--telepathy-glib/base-room-config.c10
-rw-r--r--telepathy-glib/call-content-media-description.c10
-rw-r--r--telepathy-glib/call-stream-endpoint.c20
-rw-r--r--telepathy-glib/channel-manager-request-internal.h4
-rw-r--r--telepathy-glib/channel-manager-request.c6
-rw-r--r--telepathy-glib/cm-message-internal.h2
-rw-r--r--telepathy-glib/dbus-properties-mixin.c10
-rw-r--r--telepathy-glib/dbus.h2
-rw-r--r--telepathy-glib/debug-sender.c2
-rw-r--r--telepathy-glib/group-mixin.c14
-rw-r--r--telepathy-glib/handle-channel-context-internal.h2
-rw-r--r--telepathy-glib/handle-channel-context.c12
-rw-r--r--telepathy-glib/message-mixin.c24
-rw-r--r--telepathy-glib/observe-channel-context-internal.h2
-rw-r--r--telepathy-glib/observe-channel-context.c12
-rw-r--r--telepathy-glib/presence-mixin.c4
-rw-r--r--telepathy-logger/dbus-service.c28
-rw-r--r--tests/dbus/cm.c4
-rw-r--r--tests/lib/bug-19101-conn.c2
-rw-r--r--tests/lib/contacts-conn.c22
-rw-r--r--tests/lib/dbus-tube-chan.c4
-rw-r--r--tests/lib/echo-chan.c2
-rw-r--r--tests/lib/file-transfer-chan.c8
-rw-r--r--tests/lib/room-list-chan.c6
-rw-r--r--tests/lib/simple-account-manager.c4
-rw-r--r--tests/lib/simple-account.c2
-rw-r--r--tests/lib/simple-channel-dispatch-operation.c10
-rw-r--r--tests/lib/simple-channel-dispatcher.c10
-rw-r--r--tests/lib/simple-channel-request.c6
-rw-r--r--tests/lib/simple-conn.c2
-rw-r--r--tests/lib/stream-tube-chan.c8
-rw-r--r--tests/lib/textchan-group.c4
-rw-r--r--tests/lib/tls-certificate.c10
54 files changed, 289 insertions, 289 deletions
diff --git a/docs/reference/telepathy-glib/tp-svc.xml b/docs/reference/telepathy-glib/tp-svc.xml
index 8c35d6de1..378de6cb4 100644
--- a/docs/reference/telepathy-glib/tp-svc.xml
+++ b/docs/reference/telepathy-glib/tp-svc.xml
@@ -100,7 +100,7 @@ G_DEFINE_TYPE_WITH_CODE(GabbleConnection,
<informalexample><programlisting>
void (*tp_svc_media_session_handler_error_impl)
(TpSvcMediaSessionHandler *self, guint errno, const char *message,
- DBusGMethodInvocation *context);
+ GDBusMethodInvocation *context);
</programlisting></informalexample>
and here's the beginning of the corresponding implementation:
<informalexample><programlisting>
@@ -108,7 +108,7 @@ static void
gabble_media_session_error (TpSvcMediaSessionHandler *iface,
guint errno,
const char *message,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
GabbleMediaSession *self = GABBLE_MEDIA_SESSION (iface);
@@ -134,13 +134,13 @@ gabble_media_session_error (TpSvcMediaSessionHandler *iface,
<para>
For instance, Error doesn't return anything, so
tp_svc_media_session_handler_return_from_error() doesn't take any
- parameters apart from the DBusGMethodInvocation:
+ parameters apart from the GDBusMethodInvocation:
<informalexample><programlisting>
static void
gabble_media_session_error (TpSvcMediaSessionHandler *iface,
guint errno,
const char *message,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
GabbleMediaSession *self = GABBLE_MEDIA_SESSION (iface);
diff --git a/examples/cm/call/call-channel.c b/examples/cm/call/call-channel.c
index 2985a2f7b..4699173cc 100644
--- a/examples/cm/call/call-channel.c
+++ b/examples/cm/call/call-channel.c
@@ -753,7 +753,7 @@ simulate_inability_to_unhold (gpointer p)
static void
hold_get_hold_state (TpSvcChannelInterfaceHold1 *iface,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
ExampleCallChannel *self = EXAMPLE_CALL_CHANNEL (iface);
@@ -764,7 +764,7 @@ hold_get_hold_state (TpSvcChannelInterfaceHold1 *iface,
static void
hold_request_hold (TpSvcChannelInterfaceHold1 *iface,
gboolean hold,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
ExampleCallChannel *self = EXAMPLE_CALL_CHANNEL (iface);
TpHandleRepoIface *contact_repo = tp_base_connection_get_handles
@@ -828,7 +828,7 @@ hold_request_hold (TpSvcChannelInterfaceHold1 *iface,
return;
error:
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
g_error_free (error);
}
diff --git a/examples/cm/contactlist/conn.c b/examples/cm/contactlist/conn.c
index e97663912..b1a717927 100644
--- a/examples/cm/contactlist/conn.c
+++ b/examples/cm/contactlist/conn.c
@@ -483,7 +483,7 @@ example_contact_list_connection_class_init (
static void
request_aliases (TpSvcConnectionInterfaceAliasing1 *aliasing,
const GArray *contacts,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
ExampleContactListConnection *self =
EXAMPLE_CONTACT_LIST_CONNECTION (aliasing);
@@ -499,7 +499,7 @@ request_aliases (TpSvcConnectionInterfaceAliasing1 *aliasing,
if (!tp_handles_are_valid (contact_repo, contacts, FALSE, &error))
{
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
g_error_free (error);
return;
}
@@ -525,7 +525,7 @@ request_aliases (TpSvcConnectionInterfaceAliasing1 *aliasing,
static void
set_aliases (TpSvcConnectionInterfaceAliasing1 *aliasing,
GHashTable *aliases,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
ExampleContactListConnection *self =
EXAMPLE_CONTACT_LIST_CONNECTION (aliasing);
@@ -544,7 +544,7 @@ set_aliases (TpSvcConnectionInterfaceAliasing1 *aliasing,
if (!tp_handle_is_valid (contact_repo, GPOINTER_TO_UINT (key),
&error))
{
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
g_error_free (error);
return;
}
diff --git a/examples/cm/echo-message-parts/chan.c b/examples/cm/echo-message-parts/chan.c
index 918cca673..3c128e887 100644
--- a/examples/cm/echo-message-parts/chan.c
+++ b/examples/cm/echo-message-parts/chan.c
@@ -373,7 +373,7 @@ example_echo_2_channel_class_init (ExampleEcho2ChannelClass *klass)
static void
destroyable_destroy (TpSvcChannelInterfaceDestroyable1 *iface,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseChannel *self = TP_BASE_CHANNEL (iface);
@@ -411,7 +411,7 @@ example_echo_2_channel_set_sms (ExampleEcho2Channel *self,
static void
sms_get_sms_length (TpSvcChannelInterfaceSMS1 *self,
const GPtrArray *parts,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpMessage *message;
guint i;
diff --git a/examples/cm/extended/conn.c b/examples/cm/extended/conn.c
index b6279209b..cb7846fd7 100644
--- a/examples/cm/extended/conn.c
+++ b/examples/cm/extended/conn.c
@@ -229,7 +229,7 @@ example_extended_connection_class_init (ExampleExtendedConnectionClass *klass)
static void
my_get_hats (ExampleSvcConnectionInterfaceHats *iface,
const GArray *contacts,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
ExampleExtendedConnection *self = EXAMPLE_EXTENDED_CONNECTION (iface);
TpBaseConnection *base = (TpBaseConnection *) self;
@@ -241,7 +241,7 @@ my_get_hats (ExampleSvcConnectionInterfaceHats *iface,
if (!tp_handles_are_valid (contact_repo, contacts, FALSE, &error))
{
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
g_error_free (error);
return;
}
@@ -291,7 +291,7 @@ my_set_hat (ExampleSvcConnectionInterfaceHats *iface,
const gchar *color,
guint style,
GHashTable *properties,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
ExampleExtendedConnection *self = EXAMPLE_EXTENDED_CONNECTION (iface);
TpBaseConnection *base = (TpBaseConnection *) self;
diff --git a/telepathy-glib/add-dispatch-operation-context-internal.h b/telepathy-glib/add-dispatch-operation-context-internal.h
index fdec31fce..c186ad8b1 100644
--- a/telepathy-glib/add-dispatch-operation-context-internal.h
+++ b/telepathy-glib/add-dispatch-operation-context-internal.h
@@ -55,7 +55,7 @@ TpAddDispatchOperationContext * _tp_add_dispatch_operation_context_new (
TpConnection *connection,
TpChannel *channel,
TpChannelDispatchOperation *dispatch_operation,
- DBusGMethodInvocation *dbus_context);
+ GDBusMethodInvocation *dbus_context);
TpAddDispatchOperationContextState _tp_add_dispatch_operation_context_get_state
(TpAddDispatchOperationContext *self);
diff --git a/telepathy-glib/base-call-channel.c b/telepathy-glib/base-call-channel.c
index 8c5c90397..875348bd1 100644
--- a/telepathy-glib/base-call-channel.c
+++ b/telepathy-glib/base-call-channel.c
@@ -1268,7 +1268,7 @@ tp_base_call_channel_is_accepted (TpBaseCallChannel *self)
static void
tp_base_call_channel_set_ringing (TpSvcChannelTypeCall1 *iface,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseCallChannel *self = TP_BASE_CALL_CHANNEL (iface);
TpBaseCallChannelClass *klass = TP_BASE_CALL_CHANNEL_GET_CLASS (self);
@@ -1278,13 +1278,13 @@ tp_base_call_channel_set_ringing (TpSvcChannelTypeCall1 *iface,
{
GError e = { TP_ERROR, TP_ERROR_INVALID_ARGUMENT,
"Call was requested. Ringing doesn't make sense." };
- dbus_g_method_return_error (context, &e);
+ g_dbus_method_invocation_return_gerror (context, &e);
}
else if (self->priv->state != TP_CALL_STATE_INITIALISED)
{
GError e = { TP_ERROR, TP_ERROR_NOT_AVAILABLE,
"Call is not in the right state for Ringing." };
- dbus_g_method_return_error (context, &e);
+ g_dbus_method_invocation_return_gerror (context, &e);
}
else
{
@@ -1309,7 +1309,7 @@ tp_base_call_channel_set_ringing (TpSvcChannelTypeCall1 *iface,
static void
tp_base_call_channel_set_queued (TpSvcChannelTypeCall1 *iface,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseCallChannel *self = TP_BASE_CALL_CHANNEL (iface);
TpBaseCallChannelClass *klass = TP_BASE_CALL_CHANNEL_GET_CLASS (self);
@@ -1319,14 +1319,14 @@ tp_base_call_channel_set_queued (TpSvcChannelTypeCall1 *iface,
{
GError e = { TP_ERROR, TP_ERROR_INVALID_ARGUMENT,
"Call was requested. Queued doesn't make sense." };
- dbus_g_method_return_error (context, &e);
+ g_dbus_method_invocation_return_gerror (context, &e);
}
else if (self->priv->state != TP_CALL_STATE_INITIALISING &&
self->priv->state != TP_CALL_STATE_INITIALISED)
{
GError e = { TP_ERROR, TP_ERROR_NOT_AVAILABLE,
"Call is not in the right state for Queuing." };
- dbus_g_method_return_error (context, &e);
+ g_dbus_method_invocation_return_gerror (context, &e);
}
else
{
@@ -1351,7 +1351,7 @@ tp_base_call_channel_set_queued (TpSvcChannelTypeCall1 *iface,
static void
raise_accept_state_error (TpBaseCallChannel *self,
TpCallState expected,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
GError *e = NULL;
@@ -1360,13 +1360,13 @@ raise_accept_state_error (TpBaseCallChannel *self,
call_state_to_string (expected),
call_state_to_string (self->priv->state));
- dbus_g_method_return_error (context, e);
+ g_dbus_method_invocation_return_gerror (context, e);
g_error_free (e);
}
static void
tp_base_call_channel_accept (TpSvcChannelTypeCall1 *iface,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseCallChannel *self = TP_BASE_CALL_CHANNEL (iface);
TpBaseCallChannelClass *klass = TP_BASE_CALL_CHANNEL_GET_CLASS (self);
@@ -1429,7 +1429,7 @@ tp_base_call_channel_hangup (TpSvcChannelTypeCall1 *iface,
guint reason,
const gchar *detailed_reason,
const gchar *message,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseCallChannel *self = TP_BASE_CALL_CHANNEL (iface);
TpBaseCallChannelClass *klass = TP_BASE_CALL_CHANNEL_GET_CLASS (self);
@@ -1439,7 +1439,7 @@ tp_base_call_channel_hangup (TpSvcChannelTypeCall1 *iface,
{
GError e = { TP_ERROR, TP_ERROR_NOT_AVAILABLE,
"This call has already ended" };
- dbus_g_method_return_error (context, &e);
+ g_dbus_method_invocation_return_gerror (context, &e);
return;
}
@@ -1458,7 +1458,7 @@ tp_base_call_channel_add_content_dbus (TpSvcChannelTypeCall1 *iface,
const gchar *name,
TpMediaStreamType mtype,
TpMediaStreamDirection initial_direction,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseCallChannel *self = TP_BASE_CALL_CHANNEL (iface);
TpBaseCallChannelClass *klass = TP_BASE_CALL_CHANNEL_GET_CLASS (self);
@@ -1509,7 +1509,7 @@ tp_base_call_channel_add_content_dbus (TpSvcChannelTypeCall1 *iface,
return;
error:
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
g_error_free (error);
}
diff --git a/telepathy-glib/base-call-content.c b/telepathy-glib/base-call-content.c
index 68b7c3706..d4f9d2322 100644
--- a/telepathy-glib/base-call-content.c
+++ b/telepathy-glib/base-call-content.c
@@ -756,7 +756,7 @@ tp_base_call_content_remove_stream (TpBaseCallContent *self,
static void
tp_call_content_remove (TpSvcCall1Content *content,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseCallContent *self = TP_BASE_CALL_CONTENT (content);
@@ -764,7 +764,7 @@ tp_call_content_remove (TpSvcCall1Content *content,
{
GError error = { TP_ERROR, TP_ERROR_NOT_IMPLEMENTED,
"Contents are not mutable" };
- dbus_g_method_return_error (context, &error);
+ g_dbus_method_invocation_return_gerror (context, &error);
return;
}
@@ -864,7 +864,7 @@ _tp_base_call_content_accepted (TpBaseCallContent *self,
static void
tp_call_content_start_tone (TpSvcCall1ContentInterfaceDTMF1 *dtmf,
guchar event,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseCallContent *self = TP_BASE_CALL_CONTENT (dtmf);
TpBaseCallContentClass *klass = TP_BASE_CALL_CONTENT_GET_CLASS (self);
@@ -874,13 +874,13 @@ tp_call_content_start_tone (TpSvcCall1ContentInterfaceDTMF1 *dtmf,
{
GError err = {G_DBUS_ERROR, G_DBUS_ERROR_UNKNOWN_METHOD,
"Method does not exist"};
- dbus_g_method_return_error (context, &err);
+ g_dbus_method_invocation_return_gerror (context, &err);
return;
}
if (!klass->start_tone (self, event, &error))
{
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
g_clear_error (&error);
return;
}
@@ -890,7 +890,7 @@ tp_call_content_start_tone (TpSvcCall1ContentInterfaceDTMF1 *dtmf,
static void
tp_call_content_stop_tone (TpSvcCall1ContentInterfaceDTMF1 *dtmf,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseCallContent *self = TP_BASE_CALL_CONTENT (dtmf);
TpBaseCallContentClass *klass = TP_BASE_CALL_CONTENT_GET_CLASS (self);
@@ -900,13 +900,13 @@ tp_call_content_stop_tone (TpSvcCall1ContentInterfaceDTMF1 *dtmf,
{
GError err = {G_DBUS_ERROR, G_DBUS_ERROR_UNKNOWN_METHOD,
"Method does not exist"};
- dbus_g_method_return_error (context, &err);
+ g_dbus_method_invocation_return_gerror (context, &err);
return;
}
if (!klass->stop_tone (self, &error))
{
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
g_clear_error (&error);
return;
}
@@ -917,7 +917,7 @@ tp_call_content_stop_tone (TpSvcCall1ContentInterfaceDTMF1 *dtmf,
static void
tp_call_content_multiple_tones (TpSvcCall1ContentInterfaceDTMF1 *dtmf,
const gchar *tones,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseCallContent *self = TP_BASE_CALL_CONTENT (dtmf);
TpBaseCallContentClass *klass = TP_BASE_CALL_CONTENT_GET_CLASS (self);
@@ -927,13 +927,13 @@ tp_call_content_multiple_tones (TpSvcCall1ContentInterfaceDTMF1 *dtmf,
{
GError err = {G_DBUS_ERROR, G_DBUS_ERROR_UNKNOWN_METHOD,
"Method does not exist"};
- dbus_g_method_return_error (context, &err);
+ g_dbus_method_invocation_return_gerror (context, &err);
return;
}
if (!klass->multiple_tones (self, tones, &error))
{
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
g_clear_error (&error);
return;
}
diff --git a/telepathy-glib/base-call-stream.c b/telepathy-glib/base-call-stream.c
index 370a1c473..7bfbe8039 100644
--- a/telepathy-glib/base-call-stream.c
+++ b/telepathy-glib/base-call-stream.c
@@ -742,7 +742,7 @@ tp_base_call_stream_remove_member (TpBaseCallStream *self,
static void
tp_base_call_stream_set_sending_dbus (TpSvcCall1Stream *iface,
gboolean sending,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseCallStream *self = TP_BASE_CALL_STREAM (iface);
GError *error = NULL;
@@ -756,7 +756,7 @@ tp_base_call_stream_set_sending_dbus (TpSvcCall1Stream *iface,
}
else
{
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
}
g_clear_error (&error);
@@ -766,7 +766,7 @@ static void
tp_base_call_stream_request_receiving (TpSvcCall1Stream *iface,
TpHandle contact,
gboolean receiving,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseCallStream *self = TP_BASE_CALL_STREAM (iface);
TpBaseCallStreamClass *klass = TP_BASE_CALL_STREAM_GET_CLASS (self);
@@ -825,7 +825,7 @@ out:
return;
error:
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
g_clear_error (&error);
}
diff --git a/telepathy-glib/base-channel.c b/telepathy-glib/base-channel.c
index 7e3ee42b2..4bf686612 100644
--- a/telepathy-glib/base-channel.c
+++ b/telepathy-glib/base-channel.c
@@ -1066,7 +1066,7 @@ tp_base_channel_class_init (TpBaseChannelClass *tp_base_channel_class)
static void
tp_base_channel_close_dbus (
TpSvcChannel *iface,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseChannel *chan = TP_BASE_CHANNEL (iface);
diff --git a/telepathy-glib/base-client.c b/telepathy-glib/base-client.c
index 3eca973dc..443dc1e47 100644
--- a/telepathy-glib/base-client.c
+++ b/telepathy-glib/base-client.c
@@ -1650,7 +1650,7 @@ _tp_base_client_observe_channel (TpSvcClientObserver *iface,
const gchar *dispatch_operation_path,
GHashTable *requests_hash,
GHashTable *observer_info,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseClient *self = TP_BASE_CLIENT (iface);
TpObserveChannelContext *ctx;
@@ -1817,7 +1817,7 @@ static void
_tp_base_client_add_dispatch_operation (TpSvcClientApprover *iface,
const gchar *dispatch_operation_path,
GHashTable *properties,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseClient *self = TP_BASE_CLIENT (iface);
TpAddDispatchOperationContext *ctx;
@@ -2165,7 +2165,7 @@ _tp_base_client_handle_channel (TpSvcClientHandler *iface,
GHashTable *requests_hash,
gint64 user_action_time,
GHashTable *handler_info,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseClient *self = TP_BASE_CLIENT (iface);
TpHandleChannelContext *ctx;
@@ -2321,7 +2321,7 @@ static void
_tp_base_client_add_request (TpSvcClientInterfaceRequests *iface,
const gchar *path,
GHashTable *properties,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseClient *self = TP_BASE_CLIENT (iface);
TpChannelRequest *request;
@@ -2381,7 +2381,7 @@ _tp_base_client_remove_request (TpSvcClientInterfaceRequests *iface,
const gchar *path,
const gchar *error,
const gchar *reason,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseClient *self = TP_BASE_CLIENT (iface);
TpChannelRequest *request;
diff --git a/telepathy-glib/base-connection-manager.c b/telepathy-glib/base-connection-manager.c
index b68d44236..b21accb75 100644
--- a/telepathy-glib/base-connection-manager.c
+++ b/telepathy-glib/base-connection-manager.c
@@ -740,7 +740,7 @@ static void
tp_base_connection_manager_request_connection (TpSvcConnectionManager *iface,
const gchar *proto,
GHashTable *parameters,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseConnectionManager *self = TP_BASE_CONNECTION_MANAGER (iface);
TpBaseConnectionManagerClass *cls =
@@ -800,7 +800,7 @@ tp_base_connection_manager_request_connection (TpSvcConnectionManager *iface,
return;
ERROR:
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
g_error_free (error);
}
diff --git a/telepathy-glib/base-connection.h b/telepathy-glib/base-connection.h
index bbbb60370..45fd6d7a3 100644
--- a/telepathy-glib/base-connection.h
+++ b/telepathy-glib/base-connection.h
@@ -198,7 +198,7 @@ gboolean tp_base_connection_channel_manager_iter_next (
\
if (!tp_base_connection_check_connected (c_, &e_)) \
{ \
- dbus_g_method_return_error ((context), e_); \
+ g_dbus_method_invocation_return_gerror ((context), e_); \
g_error_free (e_); \
return; \
} \
diff --git a/telepathy-glib/base-media-call-channel.c b/telepathy-glib/base-media-call-channel.c
index 508e14569..ee093d8ea 100644
--- a/telepathy-glib/base-media-call-channel.c
+++ b/telepathy-glib/base-media-call-channel.c
@@ -461,7 +461,7 @@ hold_change_failed (TpBaseMediaCallChannel *self)
static void
tp_base_media_call_channel_get_hold_state (
TpSvcChannelInterfaceHold1 *hold_iface,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseMediaCallChannel *self = TP_BASE_MEDIA_CALL_CHANNEL (hold_iface);
@@ -473,7 +473,7 @@ static void
tp_base_media_call_channel_request_hold (
TpSvcChannelInterfaceHold1 *hold_iface,
gboolean hold,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseMediaCallChannel *self = TP_BASE_MEDIA_CALL_CHANNEL (hold_iface);
diff --git a/telepathy-glib/base-media-call-content.c b/telepathy-glib/base-media-call-content.c
index 6e94dd6f2..cfa0aff4e 100644
--- a/telepathy-glib/base-media-call-content.c
+++ b/telepathy-glib/base-media-call-content.c
@@ -676,7 +676,7 @@ static void
tp_base_media_call_content_update_local_media_description (
TpSvcCall1ContentInterfaceMedia *iface,
GHashTable *properties,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseMediaCallContent *self = TP_BASE_MEDIA_CALL_CONTENT (iface);
GHashTable *current_properties;
@@ -691,7 +691,7 @@ tp_base_media_call_content_update_local_media_description (
{
GError error = { TP_ERROR, TP_ERROR_INVALID_ARGUMENT,
"The media description is missing the RemoteContact key." };
- dbus_g_method_return_error (context, &error);
+ g_dbus_method_invocation_return_gerror (context, &error);
return;
}
@@ -703,7 +703,7 @@ tp_base_media_call_content_update_local_media_description (
{
GError error = { TP_ERROR, TP_ERROR_NOT_AVAILABLE,
"The initial MediaDescription object has not yet appeared" };
- dbus_g_method_return_error (context, &error);
+ g_dbus_method_invocation_return_gerror (context, &error);
return;
}
@@ -715,7 +715,7 @@ tp_base_media_call_content_update_local_media_description (
{
GError error = { TP_ERROR, TP_ERROR_INVALID_ARGUMENT,
"Codecs can not be empty" };
- dbus_g_method_return_error (context, &error);
+ g_dbus_method_invocation_return_gerror (context, &error);
return;
}
@@ -725,7 +725,7 @@ tp_base_media_call_content_update_local_media_description (
GError error = { TP_ERROR, TP_ERROR_NOT_AVAILABLE,
"Can not update the media description while there is"
" an outstanding offer for this contact." };
- dbus_g_method_return_error (context, &error);
+ g_dbus_method_invocation_return_gerror (context, &error);
return;
}
@@ -738,7 +738,7 @@ tp_base_media_call_content_update_local_media_description (
static void
tp_base_media_call_content_fail (TpSvcCall1ContentInterfaceMedia *iface,
const GValueArray *reason_array,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseMediaCallContent *self = TP_BASE_MEDIA_CALL_CONTENT (iface);
TpBaseCallContent *content = (TpBaseCallContent *) self;
@@ -756,7 +756,7 @@ tp_base_media_call_content_acknowledge_dtmf_change (
TpSvcCall1ContentInterfaceMedia *iface,
guchar in_Event,
guint in_State,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseMediaCallContent *self = TP_BASE_MEDIA_CALL_CONTENT (iface);
@@ -764,7 +764,7 @@ tp_base_media_call_content_acknowledge_dtmf_change (
{
GError error = { TP_ERROR, TP_ERROR_INVALID_ARGUMENT,
"The acknoledgement is not for the right event"};
- dbus_g_method_return_error (context, &error);
+ g_dbus_method_invocation_return_gerror (context, &error);
return;
}
@@ -773,7 +773,7 @@ tp_base_media_call_content_acknowledge_dtmf_change (
{
GError error = { TP_ERROR, TP_ERROR_INVALID_ARGUMENT,
"The new sending state can not be a pending state"};
- dbus_g_method_return_error (context, &error);
+ g_dbus_method_invocation_return_gerror (context, &error);
return;
}
@@ -785,7 +785,7 @@ tp_base_media_call_content_acknowledge_dtmf_change (
{
GError error = { TP_ERROR, TP_ERROR_INVALID_ARGUMENT,
"Acknowledge rejected because we are not in a pending state"};
- dbus_g_method_return_error (context, &error);
+ g_dbus_method_invocation_return_gerror (context, &error);
return;
}
@@ -797,7 +797,7 @@ tp_base_media_call_content_acknowledge_dtmf_change (
{
GError error = { TP_ERROR, TP_ERROR_INVALID_ARGUMENT,
"The new sending state does not match the pending state"};
- dbus_g_method_return_error (context, &error);
+ g_dbus_method_invocation_return_gerror (context, &error);
return;
}
diff --git a/telepathy-glib/base-media-call-stream.c b/telepathy-glib/base-media-call-stream.c
index 47f1d6711..f04261253 100644
--- a/telepathy-glib/base-media-call-stream.c
+++ b/telepathy-glib/base-media-call-stream.c
@@ -1203,7 +1203,7 @@ static void
tp_base_media_call_stream_complete_sending_state_change (
TpSvcCall1StreamInterfaceMedia *iface,
TpStreamFlowState state,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseMediaCallStream *self = TP_BASE_MEDIA_CALL_STREAM (iface);
TpBaseMediaCallStreamClass *klass =
@@ -1215,7 +1215,7 @@ tp_base_media_call_stream_complete_sending_state_change (
{
GError e = { TP_ERROR, TP_ERROR_INVALID_ARGUMENT,
"Invalid sending state transition" };
- dbus_g_method_return_error (context, &e);
+ g_dbus_method_invocation_return_gerror (context, &e);
return;
}
@@ -1243,7 +1243,7 @@ tp_base_media_call_stream_report_sending_failure (
TpCallStateChangeReason reason,
const gchar *dbus_reason,
const gchar *message,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseMediaCallStream *self = TP_BASE_MEDIA_CALL_STREAM (iface);
TpBaseMediaCallStreamClass *klass =
@@ -1289,7 +1289,7 @@ static void
tp_base_media_call_stream_complete_receiving_state_change (
TpSvcCall1StreamInterfaceMedia *iface,
TpStreamFlowState state,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseMediaCallStream *self = TP_BASE_MEDIA_CALL_STREAM (iface);
TpBaseMediaCallStreamClass *klass =
@@ -1301,7 +1301,7 @@ tp_base_media_call_stream_complete_receiving_state_change (
{
GError e = { TP_ERROR, TP_ERROR_INVALID_ARGUMENT,
"Invalid receiving state transition" };
- dbus_g_method_return_error (context, &e);
+ g_dbus_method_invocation_return_gerror (context, &e);
return;
}
@@ -1338,7 +1338,7 @@ tp_base_media_call_stream_report_receiving_failure (
TpCallStateChangeReason reason,
const gchar *dbus_reason,
const gchar *message,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseMediaCallStream *self = TP_BASE_MEDIA_CALL_STREAM (iface);
TpBaseMediaCallStreamClass *klass =
@@ -1381,7 +1381,7 @@ static void
tp_base_media_call_stream_set_credentials (TpSvcCall1StreamInterfaceMedia *iface,
const gchar *username,
const gchar *password,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseMediaCallStream *self = TP_BASE_MEDIA_CALL_STREAM (iface);
@@ -1406,7 +1406,7 @@ tp_base_media_call_stream_set_credentials (TpSvcCall1StreamInterfaceMedia *iface
static void
tp_base_media_call_stream_add_candidates (TpSvcCall1StreamInterfaceMedia *iface,
const GPtrArray *candidates,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseMediaCallStream *self = TP_BASE_MEDIA_CALL_STREAM (iface);
TpBaseMediaCallStreamClass *klass =
@@ -1420,7 +1420,7 @@ tp_base_media_call_stream_add_candidates (TpSvcCall1StreamInterfaceMedia *iface,
GError e = { TP_ERROR, TP_ERROR_NOT_IMPLEMENTED,
"Connection Manager did not implement "
"TpBaseMediaCallStream::add_local_candidates vmethod" };
- dbus_g_method_return_error (context, &e);
+ g_dbus_method_invocation_return_gerror (context, &e);
return;
}
@@ -1430,7 +1430,7 @@ tp_base_media_call_stream_add_candidates (TpSvcCall1StreamInterfaceMedia *iface,
accepted_candidates = klass->add_local_candidates (self, candidates, &error);
if (accepted_candidates == NULL)
{
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
g_clear_error (&error);
return;
}
@@ -1455,7 +1455,7 @@ tp_base_media_call_stream_add_candidates (TpSvcCall1StreamInterfaceMedia *iface,
static void
tp_base_media_call_stream_finish_initial_candidates (
TpSvcCall1StreamInterfaceMedia *iface,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseMediaCallStream *self = TP_BASE_MEDIA_CALL_STREAM (iface);
TpBaseMediaCallStreamClass *klass =
@@ -1465,7 +1465,7 @@ tp_base_media_call_stream_finish_initial_candidates (
if (klass->finish_initial_candidates != NULL)
if (!klass->finish_initial_candidates (self, &error))
{
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
g_clear_error (&error);
return;
}
@@ -1477,7 +1477,7 @@ tp_base_media_call_stream_finish_initial_candidates (
static void
tp_base_media_call_stream_fail (TpSvcCall1StreamInterfaceMedia *iface,
const GValueArray *reason_array,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseMediaCallStream *self = TP_BASE_MEDIA_CALL_STREAM (iface);
TpBaseCallStream *base = TP_BASE_CALL_STREAM (self);
diff --git a/telepathy-glib/base-password-channel.c b/telepathy-glib/base-password-channel.c
index 8418155fb..3bdd12021 100644
--- a/telepathy-glib/base-password-channel.c
+++ b/telepathy-glib/base-password-channel.c
@@ -504,7 +504,7 @@ tp_base_password_channel_start_mechanism_with_data (
TpSvcChannelInterfaceSASLAuthentication1 *self,
const gchar *mechanism,
const GArray *initial_data,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBasePasswordChannel *channel = TP_BASE_PASSWORD_CHANNEL (self);
TpBasePasswordChannelPrivate *priv = channel->priv;
@@ -549,14 +549,14 @@ tp_base_password_channel_start_mechanism_with_data (
error:
DEBUG ("%s", error->message);
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
g_error_free (error);
}
static void
tp_base_password_channel_accept_sasl (
TpSvcChannelInterfaceSASLAuthentication1 *self,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBasePasswordChannel *channel = TP_BASE_PASSWORD_CHANNEL (self);
TpBasePasswordChannelPrivate *priv = channel->priv;
@@ -565,7 +565,7 @@ tp_base_password_channel_accept_sasl (
{
GError *error = g_error_new (TP_ERROR, TP_ERROR_NOT_AVAILABLE,
"AcceptSASL cannot be called in state %u", priv->sasl_status);
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
g_error_free (error);
return;
}
@@ -584,7 +584,7 @@ tp_base_password_channel_abort_sasl (
TpSvcChannelInterfaceSASLAuthentication1 *self,
TpSASLAbortReason reason,
const gchar *debug_message,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBasePasswordChannel *channel = TP_BASE_PASSWORD_CHANNEL (self);
TpBasePasswordChannelPrivate *priv = channel->priv;
@@ -594,7 +594,7 @@ tp_base_password_channel_abort_sasl (
{
GError *error = g_error_new (TP_ERROR, TP_ERROR_NOT_AVAILABLE,
"AbortSASL cannot be called in state %u", priv->sasl_status);
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
g_error_free (error);
return;
}
diff --git a/telepathy-glib/base-protocol.c b/telepathy-glib/base-protocol.c
index 84d83f2f3..b232faa04 100644
--- a/telepathy-glib/base-protocol.c
+++ b/telepathy-glib/base-protocol.c
@@ -1725,7 +1725,7 @@ tp_base_protocol_new_connection (TpBaseProtocol *self,
static void
protocol_normalize_contact (TpSvcProtocol *protocol,
const gchar *contact,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseProtocol *self = TP_BASE_PROTOCOL (protocol);
TpBaseProtocolClass *cls = TP_BASE_PROTOCOL_GET_CLASS (self);
@@ -1746,7 +1746,7 @@ protocol_normalize_contact (TpSvcProtocol *protocol,
if (ret == NULL)
{
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
g_error_free (error);
}
else
@@ -1759,7 +1759,7 @@ protocol_normalize_contact (TpSvcProtocol *protocol,
static void
protocol_identify_account (TpSvcProtocol *protocol,
GHashTable *parameters,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseProtocol *self = TP_BASE_PROTOCOL (protocol);
TpBaseProtocolClass *cls = TP_BASE_PROTOCOL_GET_CLASS (self);
@@ -1787,7 +1787,7 @@ protocol_identify_account (TpSvcProtocol *protocol,
if (ret == NULL)
{
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
g_error_free (error);
}
else
@@ -1800,7 +1800,7 @@ protocol_identify_account (TpSvcProtocol *protocol,
static void
addressing_normalize_contact_uri (TpSvcProtocolInterfaceAddressing1 *protocol,
const gchar *uri,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseProtocol *self = TP_BASE_PROTOCOL (protocol);
TpProtocolAddressingInterface *iface;
@@ -1819,7 +1819,7 @@ addressing_normalize_contact_uri (TpSvcProtocolInterfaceAddressing1 *protocol,
if (ret == NULL)
{
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
g_error_free (error);
return;
}
@@ -1839,7 +1839,7 @@ static void
addressing_normalize_vcard_address (TpSvcProtocolInterfaceAddressing1 *protocol,
const gchar *vcard_field,
const gchar *vcard_address,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseProtocol *self = TP_BASE_PROTOCOL (protocol);
TpProtocolAddressingInterface *iface;
@@ -1859,7 +1859,7 @@ addressing_normalize_vcard_address (TpSvcProtocolInterfaceAddressing1 *protocol,
if (ret == NULL)
{
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
g_error_free (error);
return;
}
diff --git a/telepathy-glib/call-content-media-description.c b/telepathy-glib/call-content-media-description.c
index 8a144af4c..8cbd324e3 100644
--- a/telepathy-glib/call-content-media-description.c
+++ b/telepathy-glib/call-content-media-description.c
@@ -1185,7 +1185,7 @@ _tp_call_content_media_description_dup_properties (
static void
tp_call_content_media_description_accept (TpSvcCall1ContentMediaDescription *iface,
GHashTable *properties,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpCallContentMediaDescription *self = (TpCallContentMediaDescription *) iface;
GPtrArray *codecs;
@@ -1208,7 +1208,7 @@ tp_call_content_media_description_accept (TpSvcCall1ContentMediaDescription *ifa
{
GError error = { TP_ERROR, TP_ERROR_INVALID_ARGUMENT,
"Codecs can not be empty" };
- dbus_g_method_return_error (context, &error);
+ g_dbus_method_invocation_return_gerror (context, &error);
return;
}
@@ -1219,7 +1219,7 @@ tp_call_content_media_description_accept (TpSvcCall1ContentMediaDescription *ifa
{
GError error = { TP_ERROR, TP_ERROR_INVALID_ARGUMENT,
"Remote contact must the same as in request." };
- dbus_g_method_return_error (context, &error);
+ g_dbus_method_invocation_return_gerror (context, &error);
return;
}
@@ -1236,7 +1236,7 @@ tp_call_content_media_description_accept (TpSvcCall1ContentMediaDescription *ifa
static void
tp_call_content_media_description_reject (TpSvcCall1ContentMediaDescription *iface,
const GValueArray *reason_array,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpCallContentMediaDescription *self = (TpCallContentMediaDescription *) iface;
@@ -1246,7 +1246,7 @@ tp_call_content_media_description_reject (TpSvcCall1ContentMediaDescription *ifa
{
GError error = { TP_ERROR, TP_ERROR_INVALID_ARGUMENT,
"Can not reject an empty Media Description" };
- dbus_g_method_return_error (context, &error);
+ g_dbus_method_invocation_return_gerror (context, &error);
return;
}
diff --git a/telepathy-glib/call-stream-endpoint.c b/telepathy-glib/call-stream-endpoint.c
index bdd1e53b4..929e9113e 100644
--- a/telepathy-glib/call-stream-endpoint.c
+++ b/telepathy-glib/call-stream-endpoint.c
@@ -764,7 +764,7 @@ static void
call_stream_endpoint_set_selected_candidate_pair (TpSvcCall1StreamEndpoint *iface,
const GValueArray *local_candidate,
const GValueArray *remote_candidate,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpCallStreamEndpoint *self = TP_CALL_STREAM_ENDPOINT (iface);
TpStreamComponent component;
@@ -774,7 +774,7 @@ call_stream_endpoint_set_selected_candidate_pair (TpSvcCall1StreamEndpoint *ifac
if (!common_checks (self, local_candidate, remote_candidate, &error))
{
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
g_clear_error (&error);
return;
}
@@ -822,7 +822,7 @@ static void
call_stream_endpoint_set_endpoint_state (TpSvcCall1StreamEndpoint *iface,
TpStreamComponent component,
TpStreamEndpointState state,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpCallStreamEndpoint *self = TP_CALL_STREAM_ENDPOINT (iface);
@@ -830,7 +830,7 @@ call_stream_endpoint_set_endpoint_state (TpSvcCall1StreamEndpoint *iface,
{
GError *error = g_error_new (TP_ERROR, TP_ERROR_INVALID_ARGUMENT,
"Stream component %d is out of the valid range.", state);
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
g_error_free (error);
return;
}
@@ -839,7 +839,7 @@ call_stream_endpoint_set_endpoint_state (TpSvcCall1StreamEndpoint *iface,
{
GError *error = g_error_new (TP_ERROR, TP_ERROR_INVALID_ARGUMENT,
"Stream state %d is out of the valid range.", state);
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
g_error_free (error);
return;
}
@@ -873,14 +873,14 @@ call_stream_endpoint_accept_selected_candidate_pair (
TpSvcCall1StreamEndpoint *iface,
const GValueArray *local_candidate,
const GValueArray *remote_candidate,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpCallStreamEndpoint *self = TP_CALL_STREAM_ENDPOINT (iface);
GError *error = NULL;
if (!common_checks (self, local_candidate, remote_candidate, &error))
{
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
g_clear_error (&error);
return;
}
@@ -900,14 +900,14 @@ call_stream_endpoint_reject_selected_candidate_pair (
TpSvcCall1StreamEndpoint *iface,
const GValueArray *local_candidate,
const GValueArray *remote_candidate,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpCallStreamEndpoint *self = TP_CALL_STREAM_ENDPOINT (iface);
GError *error = NULL;
if (!common_checks (self, local_candidate, remote_candidate, &error))
{
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
g_clear_error (&error);
return;
}
@@ -925,7 +925,7 @@ call_stream_endpoint_reject_selected_candidate_pair (
static void
call_stream_endpoint_set_controlling (TpSvcCall1StreamEndpoint *iface,
gboolean controlling,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpCallStreamEndpoint *self = TP_CALL_STREAM_ENDPOINT (iface);
diff --git a/telepathy-glib/channel-manager-request-internal.h b/telepathy-glib/channel-manager-request-internal.h
index f47903ea2..a23c2c978 100644
--- a/telepathy-glib/channel-manager-request-internal.h
+++ b/telepathy-glib/channel-manager-request-internal.h
@@ -46,7 +46,7 @@ struct _TpChannelManagerRequest
/*<private>*/
GObject parent;
- DBusGMethodInvocation *context;
+ GDBusMethodInvocation *context;
TpChannelManagerRequestMethod method;
gchar *channel_type;
@@ -85,7 +85,7 @@ GType tp_channel_manager_request_get_type (void);
TpChannelManagerRequestClass))
TpChannelManagerRequest * _tp_channel_manager_request_new (
- DBusGMethodInvocation *context,
+ GDBusMethodInvocation *context,
TpChannelManagerRequestMethod method,
const char *channel_type,
TpEntityType handle_type,
diff --git a/telepathy-glib/channel-manager-request.c b/telepathy-glib/channel-manager-request.c
index 75c36859c..e49d78734 100644
--- a/telepathy-glib/channel-manager-request.c
+++ b/telepathy-glib/channel-manager-request.c
@@ -95,7 +95,7 @@ tp_channel_manager_request_init (TpChannelManagerRequest *self)
TpChannelManagerRequest *
_tp_channel_manager_request_new (
- DBusGMethodInvocation *context,
+ GDBusMethodInvocation *context,
TpChannelManagerRequestMethod method,
const char *channel_type,
TpEntityType handle_type,
@@ -134,7 +134,7 @@ _tp_channel_manager_request_cancel (TpChannelManagerRequest *self)
DEBUG ("cancelling request at %p for %s/%u/%u", self,
self->channel_type, self->handle_type, self->handle);
- dbus_g_method_return_error (self->context, &error);
+ g_dbus_method_invocation_return_gerror (self->context, &error);
self->context = NULL;
}
@@ -189,6 +189,6 @@ _tp_channel_manager_request_fail (TpChannelManagerRequest *self,
"handle_type=%u, handle=%u",
self, self->channel_type, self->handle_type, self->handle);
- dbus_g_method_return_error (self->context, error);
+ g_dbus_method_invocation_return_gerror (self->context, error);
self->context = NULL;
}
diff --git a/telepathy-glib/cm-message-internal.h b/telepathy-glib/cm-message-internal.h
index 5c13da626..55424c5c2 100644
--- a/telepathy-glib/cm-message-internal.h
+++ b/telepathy-glib/cm-message-internal.h
@@ -50,7 +50,7 @@ struct _TpCMMessage {
guint32 incoming_id;
/* for sending */
- DBusGMethodInvocation *outgoing_context;
+ GDBusMethodInvocation *outgoing_context;
TpMessageSendingFlags outgoing_flags;
};
diff --git a/telepathy-glib/dbus-properties-mixin.c b/telepathy-glib/dbus-properties-mixin.c
index 050e2d8e8..555c3cc19 100644
--- a/telepathy-glib/dbus-properties-mixin.c
+++ b/telepathy-glib/dbus-properties-mixin.c
@@ -1068,7 +1068,7 @@ static void
_tp_dbus_properties_mixin_get (TpSvcDBusProperties *iface,
const gchar *interface_name,
const gchar *property_name,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
GObject *self = G_OBJECT (iface);
GValue value = { 0 };
@@ -1082,7 +1082,7 @@ _tp_dbus_properties_mixin_get (TpSvcDBusProperties *iface,
}
else
{
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
g_error_free (error);
}
}
@@ -1141,7 +1141,7 @@ tp_dbus_properties_mixin_dup_all (GObject *self,
static void
_tp_dbus_properties_mixin_get_all_dbus (TpSvcDBusProperties *iface,
const gchar *interface_name,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
GHashTable *values = tp_dbus_properties_mixin_dup_all (G_OBJECT (iface),
interface_name);
@@ -1259,7 +1259,7 @@ _tp_dbus_properties_mixin_set (TpSvcDBusProperties *iface,
const gchar *interface_name,
const gchar *property_name,
const GValue *value,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
GObject *self = G_OBJECT (iface);
GError *error = NULL;
@@ -1271,7 +1271,7 @@ _tp_dbus_properties_mixin_set (TpSvcDBusProperties *iface,
}
else
{
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
g_error_free (error);
}
}
diff --git a/telepathy-glib/dbus.h b/telepathy-glib/dbus.h
index af91f383d..d1ac97a58 100644
--- a/telepathy-glib/dbus.h
+++ b/telepathy-glib/dbus.h
@@ -34,7 +34,7 @@
G_BEGIN_DECLS
-void tp_dbus_g_method_return_not_implemented (DBusGMethodInvocation *context);
+void tp_dbus_g_method_return_not_implemented (GDBusMethodInvocation *context);
typedef enum /*< flags >*/
{
diff --git a/telepathy-glib/debug-sender.c b/telepathy-glib/debug-sender.c
index 7cbc053dd..6350220bb 100644
--- a/telepathy-glib/debug-sender.c
+++ b/telepathy-glib/debug-sender.c
@@ -282,7 +282,7 @@ tp_debug_sender_class_init (TpDebugSenderClass *klass)
static void
get_messages (TpSvcDebug1 *self,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpDebugSender *dbg = TP_DEBUG_SENDER (self);
GPtrArray *messages;
diff --git a/telepathy-glib/group-mixin.c b/telepathy-glib/group-mixin.c
index 8c9eb08c3..f299feff9 100644
--- a/telepathy-glib/group-mixin.c
+++ b/telepathy-glib/group-mixin.c
@@ -552,7 +552,7 @@ static void
tp_group_mixin_add_members_async (TpSvcChannelInterfaceGroup1 *obj,
const GArray *contacts,
const gchar *message,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
GError *error = NULL;
@@ -562,7 +562,7 @@ tp_group_mixin_add_members_async (TpSvcChannelInterfaceGroup1 *obj,
}
else
{
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
g_error_free (error);
}
}
@@ -692,7 +692,7 @@ tp_group_mixin_remove_members_async
const GArray *contacts,
const gchar *message,
guint reason,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
GError *error = NULL;
@@ -704,7 +704,7 @@ tp_group_mixin_remove_members_async
}
else
{
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
g_error_free (error);
}
}
@@ -2008,7 +2008,7 @@ tp_external_group_mixin_get_dbus_property (GObject *object,
GError na = { TP_ERROR, TP_ERROR_NOT_AVAILABLE, "I'm sure I " \
"had a group object around here somewhere?" };\
\
- dbus_g_method_return_error (context, &na); \
+ g_dbus_method_invocation_return_gerror (context, &na); \
return; \
} \
@@ -2016,7 +2016,7 @@ static void
tp_external_group_mixin_add_members_async (TpSvcChannelInterfaceGroup1 *obj,
const GArray *contacts,
const gchar *message,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
EXTERNAL_OR_DIE (group)
tp_group_mixin_add_members_async ((TpSvcChannelInterfaceGroup1 *) group,
@@ -2029,7 +2029,7 @@ tp_external_group_mixin_remove_members_async
const GArray *contacts,
const gchar *message,
guint reason,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
EXTERNAL_OR_DIE (group)
tp_group_mixin_remove_members_async
diff --git a/telepathy-glib/handle-channel-context-internal.h b/telepathy-glib/handle-channel-context-internal.h
index 954915e0b..cbd3e66d2 100644
--- a/telepathy-glib/handle-channel-context-internal.h
+++ b/telepathy-glib/handle-channel-context-internal.h
@@ -59,7 +59,7 @@ TpHandleChannelContext * _tp_handle_channel_context_new (
GPtrArray *requests_satisfied,
guint64 user_action_time,
GVariant *handler_info,
- DBusGMethodInvocation *dbus_context);
+ GDBusMethodInvocation *dbus_context);
TpHandleChannelContextState _tp_handle_channel_context_get_state
(TpHandleChannelContext *self);
diff --git a/telepathy-glib/message-mixin.c b/telepathy-glib/message-mixin.c
index 6dc7c4437..9d9f5c516 100644
--- a/telepathy-glib/message-mixin.c
+++ b/telepathy-glib/message-mixin.c
@@ -389,7 +389,7 @@ tp_message_mixin_maybe_send_gone (GObject *object)
static void
tp_message_mixin_set_chat_state_async (TpSvcChannelInterfaceChatState1 *iface,
guint state,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
GObject *object = (GObject *) iface;
TpMessageMixin *mixin = TP_MESSAGE_MIXIN (object);
@@ -432,7 +432,7 @@ tp_message_mixin_set_chat_state_async (TpSvcChannelInterfaceChatState1 *iface,
return;
error:
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
g_clear_error (&error);
}
@@ -536,7 +536,7 @@ static void
tp_message_mixin_acknowledge_pending_messages_async (
TpSvcChannelTypeText *iface,
const GArray *ids,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpMessageMixin *mixin = TP_MESSAGE_MIXIN (iface);
GPtrArray *links = g_ptr_array_sized_new (ids->len);
@@ -568,7 +568,7 @@ tp_message_mixin_acknowledge_pending_messages_async (
"invalid message id %u", id);
DEBUG ("%s", error->message);
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
g_error_free (error);
g_ptr_array_unref (links);
@@ -747,7 +747,7 @@ tp_message_mixin_set_rescued (GObject *obj)
struct _TpMessageMixinOutgoingMessagePrivate {
- DBusGMethodInvocation *context;
+ GDBusMethodInvocation *context;
gboolean messages:1;
};
@@ -795,7 +795,7 @@ tp_message_mixin_sent (GObject *object,
{
GError *e = g_error_copy (error);
- dbus_g_method_return_error (cm_msg->outgoing_context, e);
+ g_dbus_method_invocation_return_gerror (cm_msg->outgoing_context, e);
g_error_free (e);
}
else
@@ -829,7 +829,7 @@ static void
tp_message_mixin_send_message_async (TpSvcChannelTypeText *iface,
const GPtrArray *parts,
guint flags,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpMessageMixin *mixin = TP_MESSAGE_MIXIN (iface);
TpMessage *message;
@@ -850,7 +850,7 @@ tp_message_mixin_send_message_async (TpSvcChannelTypeText *iface,
GError e = { TP_ERROR, TP_ERROR_INVALID_ARGUMENT,
"Cannot send a message that does not have at least one part" };
- dbus_g_method_return_error (context, &e);
+ g_dbus_method_invocation_return_gerror (context, &e);
return;
}
@@ -866,7 +866,7 @@ tp_message_mixin_send_message_async (TpSvcChannelTypeText *iface,
TP_ERROR_INVALID_ARGUMENT,
"Key '%s' not allowed in a sent message", *iter);
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
return;
}
}
@@ -880,7 +880,7 @@ tp_message_mixin_send_message_async (TpSvcChannelTypeText *iface,
TP_ERROR_INVALID_ARGUMENT,
"Key '%s' not allowed in a message header", *iter);
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
return;
}
}
@@ -893,7 +893,7 @@ tp_message_mixin_send_message_async (TpSvcChannelTypeText *iface,
TP_ERROR_INVALID_ARGUMENT,
"Key '%s' not allowed in an outgoing message header", *iter);
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
return;
}
}
@@ -909,7 +909,7 @@ tp_message_mixin_send_message_async (TpSvcChannelTypeText *iface,
TP_ERROR_INVALID_ARGUMENT,
"Key '%s' not allowed in a message body", *iter);
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
return;
}
}
diff --git a/telepathy-glib/observe-channel-context-internal.h b/telepathy-glib/observe-channel-context-internal.h
index e3e363228..bc21bada5 100644
--- a/telepathy-glib/observe-channel-context-internal.h
+++ b/telepathy-glib/observe-channel-context-internal.h
@@ -60,7 +60,7 @@ TpObserveChannelContext * _tp_observe_channel_context_new (
TpChannelDispatchOperation *dispatch_operation,
GPtrArray *requests,
GHashTable *observer_info,
- DBusGMethodInvocation *dbus_context);
+ GDBusMethodInvocation *dbus_context);
TpObserveChannelContextState _tp_observe_channel_context_get_state (
TpObserveChannelContext *self);
diff --git a/telepathy-glib/presence-mixin.c b/telepathy-glib/presence-mixin.c
index 8b157e303..7c36feb52 100644
--- a/telepathy-glib/presence-mixin.c
+++ b/telepathy-glib/presence-mixin.c
@@ -766,7 +766,7 @@ tp_presence_mixin_set_presence (
TpSvcConnectionInterfacePresence1 *iface,
const gchar *status,
const gchar *message,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
GObject *obj = (GObject *) iface;
TpPresenceMixinClass *mixin_cls =
@@ -803,7 +803,7 @@ out:
}
else
{
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
g_error_free (error);
}
diff --git a/telepathy-logger/dbus-service.c b/telepathy-logger/dbus-service.c
index 978c485c8..3f1d7c8b7 100644
--- a/telepathy-logger/dbus-service.c
+++ b/telepathy-logger/dbus-service.c
@@ -65,7 +65,7 @@ struct _FavouriteContactClosure {
gchar *account;
gchar *contact_id;
gchar *file_contents;
- DBusGMethodInvocation *context;
+ GDBusMethodInvocation *context;
FavouriteContactCallback cb;
};
@@ -90,7 +90,7 @@ static FavouriteContactClosure *
favourite_contact_closure_new (TplDBusService *self,
const gchar *account,
const gchar *contact_id,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
FavouriteContactClosure *closure;
@@ -427,7 +427,7 @@ pendingproc_get_favourite_contacts (TplActionChain *action_chain,
static void
tpl_dbus_service_get_favourite_contacts (TpSvcLogger *logger,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TplDBusService *self;
TplDBusServicePriv *priv;
@@ -576,7 +576,7 @@ pendingproc_add_favourite_contact (TplActionChain *action_chain,
if (!tp_dbus_check_valid_object_path (closure->account, &error))
{
- dbus_g_method_return_error (closure->context, error);
+ g_dbus_method_invocation_return_gerror (closure->context, error);
goto pendingproc_add_favourite_contact_ERROR;
}
@@ -605,7 +605,7 @@ static void
tpl_dbus_service_add_favourite_contact (TpSvcLogger *logger,
const gchar *account,
const gchar *contact_id,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TplDBusService *self = TPL_DBUS_SERVICE (logger);
TplDBusServicePriv *priv;
@@ -673,7 +673,7 @@ pendingproc_remove_favourite_contact (TplActionChain *action_chain,
if (!tp_dbus_check_valid_object_path (closure->account, &error))
{
- dbus_g_method_return_error (closure->context, error);
+ g_dbus_method_invocation_return_gerror (closure->context, error);
goto pendingproc_remove_favourite_contact_ERROR;
}
@@ -706,7 +706,7 @@ static void
tpl_dbus_service_remove_favourite_contact (TpSvcLogger *logger,
const gchar *account,
const gchar *contact_id,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TplDBusService *self = TPL_DBUS_SERVICE (logger);
TplDBusServicePriv *priv;
@@ -733,7 +733,7 @@ tpl_dbus_service_remove_favourite_contact (TpSvcLogger *logger,
static void
tpl_dbus_service_clear (TpSvcLogger *logger,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TplDBusService *self = TPL_DBUS_SERVICE (logger);
@@ -750,7 +750,7 @@ tpl_dbus_service_clear (TpSvcLogger *logger,
static void
tpl_dbus_service_clear_account (TpSvcLogger *logger,
const gchar *account_path,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TplDBusService *self = TPL_DBUS_SERVICE (logger);
TpDBusDaemon *bus;
@@ -765,7 +765,7 @@ tpl_dbus_service_clear_account (TpSvcLogger *logger,
if (bus == NULL)
{
DEBUG ("Unable to acquire the bus daemon: %s", error->message);
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
goto out;
}
@@ -777,7 +777,7 @@ tpl_dbus_service_clear_account (TpSvcLogger *logger,
{
DEBUG ("Unable to acquire the account for %s: %s", account_path,
error->message);
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
goto out;
}
@@ -801,7 +801,7 @@ tpl_dbus_service_clear_entity (TpSvcLogger *logger,
const gchar *account_path,
const gchar *identifier,
gint type,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TplDBusService *self = TPL_DBUS_SERVICE (logger);
TpDBusDaemon *bus;
@@ -818,7 +818,7 @@ tpl_dbus_service_clear_entity (TpSvcLogger *logger,
if (bus == NULL)
{
DEBUG ("Unable to acquire the bus daemon: %s", error->message);
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
goto out;
}
@@ -830,7 +830,7 @@ tpl_dbus_service_clear_entity (TpSvcLogger *logger,
{
DEBUG ("Unable to acquire the account for %s: %s", account_path,
error->message);
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
goto out;
}
diff --git a/tests/dbus/cm.c b/tests/dbus/cm.c
index 32c955f2b..456615c93 100644
--- a/tests/dbus/cm.c
+++ b/tests/dbus/cm.c
@@ -62,7 +62,7 @@ static void
my_get (TpSvcDBusProperties *iface G_GNUC_UNUSED,
const gchar *i G_GNUC_UNUSED,
const gchar *p G_GNUC_UNUSED,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
/* The telepathy-glib client side should never call this:
* GetAll() is better. */
@@ -72,7 +72,7 @@ my_get (TpSvcDBusProperties *iface G_GNUC_UNUSED,
static void
my_get_all (TpSvcDBusProperties *iface,
const gchar *i,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
MyConnectionManager *cm = (MyConnectionManager *) iface;
GHashTable *ht;
diff --git a/tests/lib/bug-19101-conn.c b/tests/lib/bug-19101-conn.c
index f12e193ce..19b322a74 100644
--- a/tests/lib/bug-19101-conn.c
+++ b/tests/lib/bug-19101-conn.c
@@ -42,7 +42,7 @@ tp_tests_bug19101_connection_get_contact_by_id (
TpSvcConnection *iface,
const gchar *id,
const char **interfaces,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseConnection *base_conn = TP_BASE_CONNECTION (iface);
TpHandleRepoIface *contact_repo = tp_base_connection_get_handles (
diff --git a/tests/lib/contacts-conn.c b/tests/lib/contacts-conn.c
index a8e92869a..787aea314 100644
--- a/tests/lib/contacts-conn.c
+++ b/tests/lib/contacts-conn.c
@@ -753,7 +753,7 @@ tp_tests_contacts_connection_set_default_contact_info (
static void
my_request_aliases (TpSvcConnectionInterfaceAliasing1 *aliasing,
const GArray *contacts,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpTestsContactsConnection *self = TP_TESTS_CONTACTS_CONNECTION (aliasing);
TpBaseConnection *base = TP_BASE_CONNECTION (aliasing);
@@ -768,7 +768,7 @@ my_request_aliases (TpSvcConnectionInterfaceAliasing1 *aliasing,
if (!tp_handles_are_valid (contact_repo, contacts, FALSE, &error))
{
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
g_error_free (error);
return;
}
@@ -798,7 +798,7 @@ my_request_aliases (TpSvcConnectionInterfaceAliasing1 *aliasing,
static void
my_set_aliases (TpSvcConnectionInterfaceAliasing1 *aliasing,
GHashTable *table,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpTestsContactsConnection *self = TP_TESTS_CONTACTS_CONNECTION (aliasing);
TpBaseConnection *base = TP_BASE_CONNECTION (aliasing);
@@ -829,7 +829,7 @@ my_set_aliases (TpSvcConnectionInterfaceAliasing1 *aliasing,
/* Verify all handles are valid */
if (!tp_handles_are_valid (contact_repo, handles, FALSE, &error))
{
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
g_clear_error (&error);
goto out;
}
@@ -862,7 +862,7 @@ init_aliasing (gpointer g_iface,
static void
my_request_avatars (TpSvcConnectionInterfaceAvatars1 *avatars,
const GArray *contacts,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpTestsContactsConnection *self = TP_TESTS_CONTACTS_CONNECTION (avatars);
TpBaseConnection *base = TP_BASE_CONNECTION (avatars);
@@ -875,7 +875,7 @@ my_request_avatars (TpSvcConnectionInterfaceAvatars1 *avatars,
if (!tp_handles_are_valid (contact_repo, contacts, FALSE, &error))
{
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
g_error_free (error);
return;
}
@@ -953,7 +953,7 @@ lookup_contact_info (TpTestsContactsConnection *self,
static void
my_refresh_contact_info (TpSvcConnectionInterfaceContactInfo1 *obj,
const GArray *contacts,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpTestsContactsConnection *self = TP_TESTS_CONTACTS_CONNECTION (obj);
TpBaseConnection *base = TP_BASE_CONNECTION (obj);
@@ -966,7 +966,7 @@ my_refresh_contact_info (TpSvcConnectionInterfaceContactInfo1 *obj,
if (!tp_handles_are_valid (contact_repo, contacts, FALSE, &error))
{
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
g_error_free (error);
return;
}
@@ -988,7 +988,7 @@ my_refresh_contact_info (TpSvcConnectionInterfaceContactInfo1 *obj,
static void
my_request_contact_info (TpSvcConnectionInterfaceContactInfo1 *obj,
guint handle,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpTestsContactsConnection *self = TP_TESTS_CONTACTS_CONNECTION (obj);
TpBaseConnection *base = TP_BASE_CONNECTION (obj);
@@ -1001,7 +1001,7 @@ my_request_contact_info (TpSvcConnectionInterfaceContactInfo1 *obj,
if (!tp_handle_is_valid (contact_repo, handle, &error))
{
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
g_error_free (error);
return;
}
@@ -1017,7 +1017,7 @@ my_request_contact_info (TpSvcConnectionInterfaceContactInfo1 *obj,
static void
my_set_contact_info (TpSvcConnectionInterfaceContactInfo1 *obj,
const GPtrArray *info,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpTestsContactsConnection *self = TP_TESTS_CONTACTS_CONNECTION (obj);
TpBaseConnection *base = TP_BASE_CONNECTION (obj);
diff --git a/tests/lib/dbus-tube-chan.c b/tests/lib/dbus-tube-chan.c
index d2de191e0..ab307d247 100644
--- a/tests/lib/dbus-tube-chan.c
+++ b/tests/lib/dbus-tube-chan.c
@@ -353,7 +353,7 @@ static void
dbus_tube_offer (TpSvcChannelTypeDBusTube1 *chan,
GHashTable *parameters,
guint access_control,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpTestsDBusTubeChannel *self = (TpTestsDBusTubeChannel *) chan;
@@ -374,7 +374,7 @@ dbus_tube_offer (TpSvcChannelTypeDBusTube1 *chan,
static void
dbus_tube_accept (TpSvcChannelTypeDBusTube1 *chan,
guint access_control,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpTestsDBusTubeChannel *self = (TpTestsDBusTubeChannel *) chan;
diff --git a/tests/lib/echo-chan.c b/tests/lib/echo-chan.c
index c5a6465d2..fd28e5003 100644
--- a/tests/lib/echo-chan.c
+++ b/tests/lib/echo-chan.c
@@ -202,7 +202,7 @@ text_send (GObject *object,
static void
destroyable_destroy (TpSvcChannelInterfaceDestroyable1 *iface,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpTestsEchoChannel *self = TP_TESTS_ECHO_CHANNEL (iface);
diff --git a/tests/lib/file-transfer-chan.c b/tests/lib/file-transfer-chan.c
index 87f6d3f33..3951eccbc 100644
--- a/tests/lib/file-transfer-chan.c
+++ b/tests/lib/file-transfer-chan.c
@@ -448,7 +448,7 @@ file_transfer_provide_file (TpSvcChannelTypeFileTransfer1 *iface,
TpSocketAddressType address_type,
TpSocketAccessControl access_control,
const GValue *access_control_param,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpTestsFileTransferChannel *self = (TpTestsFileTransferChannel *) iface;
TpBaseChannel *base_chan = (TpBaseChannel *) iface;
@@ -512,7 +512,7 @@ file_transfer_provide_file (TpSvcChannelTypeFileTransfer1 *iface,
return;
fail:
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
g_error_free (error);
}
@@ -522,7 +522,7 @@ file_transfer_accept_file (TpSvcChannelTypeFileTransfer1 *iface,
TpSocketAccessControl access_control,
const GValue *access_control_param,
guint64 offset,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpTestsFileTransferChannel *self = (TpTestsFileTransferChannel *) iface;
TpBaseChannel *base_chan = (TpBaseChannel *) iface;
@@ -577,7 +577,7 @@ file_transfer_accept_file (TpSvcChannelTypeFileTransfer1 *iface,
return;
fail:
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
g_error_free (error);
}
diff --git a/tests/lib/room-list-chan.c b/tests/lib/room-list-chan.c
index a71b29cbc..da1ecc236 100644
--- a/tests/lib/room-list-chan.c
+++ b/tests/lib/room-list-chan.c
@@ -209,7 +209,7 @@ find_rooms (gpointer data)
static void
room_list_list_rooms (TpSvcChannelTypeRoomList1 *chan,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpTestsRoomListChan *self = TP_TESTS_ROOM_LIST_CHAN (chan);
@@ -218,7 +218,7 @@ room_list_list_rooms (TpSvcChannelTypeRoomList1 *chan,
GError error = { TP_ERROR, TP_ERROR_INVALID_ARGUMENT,
"Already listing" };
- dbus_g_method_return_error (context, &error);
+ g_dbus_method_invocation_return_gerror (context, &error);
return;
}
@@ -227,7 +227,7 @@ room_list_list_rooms (TpSvcChannelTypeRoomList1 *chan,
GError error = { TP_ERROR, TP_ERROR_SERVICE_CONFUSED,
"Computer says no" };
- dbus_g_method_return_error (context, &error);
+ g_dbus_method_invocation_return_gerror (context, &error);
return;
}
diff --git a/tests/lib/simple-account-manager.c b/tests/lib/simple-account-manager.c
index e5bddbc1f..767bce449 100644
--- a/tests/lib/simple-account-manager.c
+++ b/tests/lib/simple-account-manager.c
@@ -52,7 +52,7 @@ tp_tests_simple_account_manager_create_account (TpSvcAccountManager *svc,
const gchar *in_Display_Name,
GHashTable *in_Parameters,
GHashTable *in_Properties,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpTestsSimpleAccountManager *self = (TpTestsSimpleAccountManager *) svc;
const gchar *out = TP_ACCOUNT_OBJECT_PATH_BASE "gabble/jabber/lospolloshermanos";
@@ -61,7 +61,7 @@ tp_tests_simple_account_manager_create_account (TpSvcAccountManager *svc,
if (!tp_strdiff (tp_asv_get_string (in_Parameters, "fail"), "yes"))
{
GError e = { TP_ERROR, TP_ERROR_INVALID_ARGUMENT, "loldongs" };
- dbus_g_method_return_error (context, &e);
+ g_dbus_method_invocation_return_gerror (context, &e);
return;
}
diff --git a/tests/lib/simple-account.c b/tests/lib/simple-account.c
index 7f9a629b5..7f0d568bd 100644
--- a/tests/lib/simple-account.c
+++ b/tests/lib/simple-account.c
@@ -92,7 +92,7 @@ static void
tp_tests_simple_account_update_parameters (TpSvcAccount *svc,
GHashTable *parameters,
const gchar **unset_parameters,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
GPtrArray *reconnect_required = g_ptr_array_new ();
GHashTableIter iter;
diff --git a/tests/lib/simple-channel-dispatch-operation.c b/tests/lib/simple-channel-dispatch-operation.c
index 9ac06992b..8786b9370 100644
--- a/tests/lib/simple-channel-dispatch-operation.c
+++ b/tests/lib/simple-channel-dispatch-operation.c
@@ -58,27 +58,27 @@ tp_tests_simple_channel_dispatch_operation_handle_with (
TpSvcChannelDispatchOperation *iface,
const gchar *handler,
gint64 user_action_timestamp,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
if (!tp_strdiff (handler, "FAIL"))
{
GError error = { TP_ERROR, TP_ERROR_INVALID_ARGUMENT, "Nope" };
- dbus_g_method_return_error (context, &error);
+ g_dbus_method_invocation_return_gerror (context, &error);
return;
}
- dbus_g_method_return (context);
+ g_dbus_method_invocation_return_value (context, NULL);
}
static void
tp_tests_simple_channel_dispatch_operation_claim (
TpSvcChannelDispatchOperation *iface,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
tp_svc_channel_dispatch_operation_emit_finished (iface, "", "");
- dbus_g_method_return (context);
+ g_dbus_method_invocation_return_value (context, NULL);
}
static void
diff --git a/tests/lib/simple-channel-dispatcher.c b/tests/lib/simple-channel-dispatcher.c
index 49516bb8a..450df5654 100644
--- a/tests/lib/simple-channel-dispatcher.c
+++ b/tests/lib/simple-channel-dispatcher.c
@@ -122,7 +122,7 @@ tp_tests_simple_channel_dispatcher_create_channel (
gint64 user_action_time,
const gchar *preferred_handler,
GHashTable *hints,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpTestsSimpleChannelDispatcher *self = SIMPLE_CHANNEL_DISPATCHER (dispatcher);
gchar *path;
@@ -144,7 +144,7 @@ tp_tests_simple_channel_dispatcher_create_channel (
GError error = { TP_ERROR, TP_ERROR_INVALID_ARGUMENT,
"Computer says no" };
- dbus_g_method_return_error (context, &error);
+ g_dbus_method_invocation_return_gerror (context, &error);
return;
}
@@ -169,7 +169,7 @@ tp_tests_simple_channel_dispatcher_ensure_channel (
gint64 user_action_time,
const gchar *preferred_handler,
GHashTable *hints,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpTestsSimpleChannelDispatcher *self = SIMPLE_CHANNEL_DISPATCHER (dispatcher);
gchar *path;
@@ -219,7 +219,7 @@ tp_tests_simple_channel_dispatcher_delegate_channels (
const GPtrArray *channels,
gint64 user_action_time,
const gchar *preferred_handler,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpTestsSimpleChannelDispatcher *self = (TpTestsSimpleChannelDispatcher *)
dispatcher;
@@ -262,7 +262,7 @@ tp_tests_simple_channel_dispatcher_present_channel (
TpSvcChannelDispatcher *dispatcher,
const gchar *channel,
gint64 user_action_time,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
tp_svc_channel_dispatcher_return_from_present_channel (context);
}
diff --git a/tests/lib/simple-channel-request.c b/tests/lib/simple-channel-request.c
index bb6687c54..61be33e03 100644
--- a/tests/lib/simple-channel-request.c
+++ b/tests/lib/simple-channel-request.c
@@ -141,7 +141,7 @@ tp_tests_simple_channel_request_dup_immutable_props (
static void
tp_tests_simple_channel_request_proceed (TpSvcChannelRequest *request,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpTestsSimpleChannelRequest *self = SIMPLE_CHANNEL_REQUEST (request);
TpClient *client;
@@ -161,7 +161,7 @@ tp_tests_simple_channel_request_proceed (TpSvcChannelRequest *request,
GError error = { TP_ERROR, TP_ERROR_INVALID_ARGUMENT,
"Computer says no" };
- dbus_g_method_return_error (context, &error);
+ g_dbus_method_invocation_return_gerror (context, &error);
return;
}
@@ -243,7 +243,7 @@ tp_tests_simple_channel_request_proceed (TpSvcChannelRequest *request,
static void
tp_tests_simple_channel_request_cancel (TpSvcChannelRequest *request,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
tp_svc_channel_request_emit_failed (request, TP_ERROR_STR_CANCELLED,
"ChannelRequest has been cancelled");
diff --git a/tests/lib/simple-conn.c b/tests/lib/simple-conn.c
index 34244efb4..efa20c0dd 100644
--- a/tests/lib/simple-conn.c
+++ b/tests/lib/simple-conn.c
@@ -420,7 +420,7 @@ tp_tests_simple_connection_ensure_room_list_chan (TpTestsSimpleConnection *self,
static void
get_all (TpSvcDBusProperties *iface,
const gchar *interface_name,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
GHashTable *values = tp_dbus_properties_mixin_dup_all (G_OBJECT (iface),
interface_name);
diff --git a/tests/lib/stream-tube-chan.c b/tests/lib/stream-tube-chan.c
index 8a41064d0..39b4dc1fd 100644
--- a/tests/lib/stream-tube-chan.c
+++ b/tests/lib/stream-tube-chan.c
@@ -375,7 +375,7 @@ stream_tube_offer (TpSvcChannelTypeStreamTube1 *iface,
const GValue *address,
guint access_control,
GHashTable *parameters,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpTestsStreamTubeChannel *self = (TpTestsStreamTubeChannel *) iface;
GError *error = NULL;
@@ -404,7 +404,7 @@ stream_tube_offer (TpSvcChannelTypeStreamTube1 *iface,
return;
fail:
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
g_error_free (error);
}
@@ -465,7 +465,7 @@ stream_tube_accept (TpSvcChannelTypeStreamTube1 *iface,
TpSocketAddressType address_type,
TpSocketAccessControl access_control,
const GValue *access_control_param,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpTestsStreamTubeChannel *self = (TpTestsStreamTubeChannel *) iface;
GError *error = NULL;
@@ -503,7 +503,7 @@ stream_tube_accept (TpSvcChannelTypeStreamTube1 *iface,
return;
fail:
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
g_error_free (error);
}
diff --git a/tests/lib/textchan-group.c b/tests/lib/textchan-group.c
index 7975b0fd3..068ba463e 100644
--- a/tests/lib/textchan-group.c
+++ b/tests/lib/textchan-group.c
@@ -266,7 +266,7 @@ tp_tests_text_channel_set_password (TpTestsTextChannelGroup *self,
static void
password_get_password_flags (TpSvcChannelInterfacePassword1 *chan,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpTestsTextChannelGroup *self = (TpTestsTextChannelGroup *) chan;
TpChannelPasswordFlags flags = 0;
@@ -281,7 +281,7 @@ password_get_password_flags (TpSvcChannelInterfacePassword1 *chan,
static void
password_provide_password (TpSvcChannelInterfacePassword1 *chan,
const gchar *password,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpTestsTextChannelGroup *self = (TpTestsTextChannelGroup *) chan;
diff --git a/tests/lib/tls-certificate.c b/tests/lib/tls-certificate.c
index 0da164562..9a1d441c5 100644
--- a/tests/lib/tls-certificate.c
+++ b/tests/lib/tls-certificate.c
@@ -256,7 +256,7 @@ tp_tests_tls_certificate_class_init (TpTestsTLSCertificateClass *klass)
static void
tp_tests_tls_certificate_accept (TpSvcAuthenticationTLSCertificate *cert,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpTestsTLSCertificate *self = TP_TESTS_TLS_CERTIFICATE (cert);
@@ -272,7 +272,7 @@ tp_tests_tls_certificate_accept (TpSvcAuthenticationTLSCertificate *cert,
"doesn't make sense."
};
- dbus_g_method_return_error (context, &error);
+ g_dbus_method_invocation_return_gerror (context, &error);
return;
}
@@ -285,7 +285,7 @@ tp_tests_tls_certificate_accept (TpSvcAuthenticationTLSCertificate *cert,
static void
tp_tests_tls_certificate_reject (TpSvcAuthenticationTLSCertificate *cert,
const GPtrArray *rejections,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpTestsTLSCertificate *self = TP_TESTS_TLS_CERTIFICATE (cert);
@@ -298,7 +298,7 @@ tp_tests_tls_certificate_reject (TpSvcAuthenticationTLSCertificate *cert,
GError error = { TP_ERROR, TP_ERROR_INVALID_ARGUMENT,
"Calling Reject() with a zero-length rejection list." };
- dbus_g_method_return_error (context, &error);
+ g_dbus_method_invocation_return_gerror (context, &error);
return;
}
@@ -311,7 +311,7 @@ tp_tests_tls_certificate_reject (TpSvcAuthenticationTLSCertificate *cert,
"doesn't make sense."
};
- dbus_g_method_return_error (context, &error);
+ g_dbus_method_invocation_return_gerror (context, &error);
return;
}
diff --git a/telepathy-glib/add-dispatch-operation-context.c b/telepathy-glib/add-dispatch-operation-context.c
index b7a5e84d5..ebaec360c 100644
--- a/telepathy-glib/add-dispatch-operation-context.c
+++ b/telepathy-glib/add-dispatch-operation-context.c
@@ -78,7 +78,7 @@ struct _TpAddDispatchOperationContextPrivate
{
TpAddDispatchOperationContextState state;
GSimpleAsyncResult *result;
- DBusGMethodInvocation *dbus_context;
+ GDBusMethodInvocation *dbus_context;
/* Number of calls we are waiting they return. Once they have all returned
* the context is considered as prepared */
@@ -324,14 +324,14 @@ tp_add_dispatch_operation_context_class_init (
/**
* TpAddDispatchOperationContext:dbus-context: (skip)
*
* The #DBusGMethodInvocation representing the D-Bus context of the
* AddDispatchOperation call.
* Can only be written during construction.
*
* Since: 0.11.5
*/
param_spec = g_param_spec_pointer ("dbus-context", "D-Bus context",
- "The DBusGMethodInvocation associated with the AddDispatchOperation call",
+ "The GDBusMethodInvocation associated with the AddDispatchOperation call",
G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS);
g_object_class_install_property (object_class, PROP_DBUS_CONTEXT,
param_spec);
@@ -343,7 +343,7 @@ _tp_add_dispatch_operation_context_new (
TpConnection *connection,
TpChannel *channel,
TpChannelDispatchOperation *dispatch_operation,
- DBusGMethodInvocation *dbus_context)
+ GDBusMethodInvocation *dbus_context)
{
return g_object_new (TP_TYPE_ADD_DISPATCH_OPERATION_CONTEXT,
"account", account,
@@ -372,7 +372,7 @@ tp_add_dispatch_operation_context_accept (TpAddDispatchOperationContext *self)
g_return_if_fail (self->priv->dbus_context != NULL);
self->priv->state = TP_ADD_DISPATCH_OPERATION_CONTEXT_STATE_DONE;
- dbus_g_method_return (self->priv->dbus_context);
+ g_dbus_method_invocation_return_value (self->priv->dbus_context, NULL);
self->priv->dbus_context = NULL;
}
@@ -396,7 +396,7 @@ tp_add_dispatch_operation_context_fail (TpAddDispatchOperationContext *self,
g_return_if_fail (self->priv->dbus_context != NULL);
self->priv->state = TP_ADD_DISPATCH_OPERATION_CONTEXT_STATE_FAILED;
- dbus_g_method_return_error (self->priv->dbus_context, error);
+ g_dbus_method_invocation_return_gerror (self->priv->dbus_context, error);
self->priv->dbus_context = NULL;
}
@@ -324,14 +324,14 @@ tp_add_dispatch_operation_context_class_init (
* TpAddDispatchOperationContext:dbus-context: (skip)
*
- * The #DBusGMethodInvocation representing the D-Bus context of the
+ * The #GDBusMethodInvocation representing the D-Bus context of the
* AddDispatchOperation call.
* Can only be written during construction.
diff --git a/telepathy-glib/base-connection.c b/telepathy-glib/base-connection.c
index 42909ca5f..c0d3ad8e0 100644
--- a/telepathy-glib/base-connection.c
+++ b/telepathy-glib/base-connection.c
@@ -221,7 +221,7 @@
/**
* TP_BASE_CONNECTION_ERROR_IF_NOT_CONNECTED: (skip)
* @conn: A TpBaseConnection
- * @context: A DBusGMethodInvocation
+ * @context: A GDBusMethodInvocation
*
* If @conn is not in state #TP_CONNECTION_STATUS_CONNECTED, complete the
* D-Bus method invocation @context by raising the Telepathy error
@@ -331,7 +331,7 @@ struct _TpBaseConnectionPrivate
* so that we can use GArray's convenient auto-null-termination. */
GArray *interfaces;
/* Array of DBusGMethodInvocation * representing Disconnect calls.
* If NULL and we are in a state != DISCONNECTED, then we have not started
* shutting down yet.
* If NULL and we are in state DISCONNECTED, then we have finished shutting
@@ -1492,7 +1492,7 @@ conn_status_reason_from_g_error (GError *error)
static void
tp_base_connection_connect (TpSvcConnection *iface,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseConnection *self = TP_BASE_CONNECTION (iface);
TpBaseConnectionClass *cls = TP_BASE_CONNECTION_GET_CLASS (self);
@@ -1519,7 +1519,7 @@ tp_base_connection_connect (TpSvcConnection *iface,
TP_CONNECTION_STATUS_DISCONNECTED,
conn_status_reason_from_g_error (error));
}
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
g_error_free (error);
return;
}
@@ -1529,7 +1529,7 @@ tp_base_connection_connect (TpSvcConnection *iface,
static void
tp_base_connection_disconnect (TpSvcConnection *iface,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseConnection *self = TP_BASE_CONNECTION (iface);
@@ -2200,7 +2200,7 @@ tp_base_connection_add_client_interest (TpBaseConnection *self,
static void
tp_base_connection_dbus_add_client_interest (TpSvcConnection *svc,
const gchar **interests,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseConnection *self = (TpBaseConnection *) svc;
gchar *unique_name = NULL;
@@ -2224,7 +2224,7 @@ finally:
static void
tp_base_connection_dbus_remove_client_interest (TpSvcConnection *svc,
const gchar **interests,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
gchar *unique_name = NULL;
const gchar **interest;
@@ -2330,25 +2330,25 @@ finally:
*/
static void conn_requests_check_basic_properties (TpBaseConnection *self,
GHashTable *requested_properties, TpChannelManagerRequestMethod method,
- DBusGMethodInvocation *context);
+ GDBusMethodInvocation *context);
static void
conn_requests_requestotron_validate_handle (TpBaseConnection *self,
GHashTable *requested_properties, TpChannelManagerRequestMethod method,
const gchar *type, TpEntityType target_entity_type,
TpHandle target_handle, const gchar *target_id,
- DBusGMethodInvocation *context);
+ GDBusMethodInvocation *context);
static void conn_requests_offer_request (TpBaseConnection *self,
GHashTable *requested_properties, TpChannelManagerRequestMethod method,
const gchar *type, TpEntityType target_entity_type,
- TpHandle target_handle, DBusGMethodInvocation *context);
+ TpHandle target_handle, GDBusMethodInvocation *context);
#define RETURN_INVALID_ARGUMENT(message) \
G_STMT_START { \
GError e = { TP_ERROR, TP_ERROR_INVALID_ARGUMENT, message }; \
- dbus_g_method_return_error (context, &e); \
+ g_dbus_method_invocation_return_gerror (context, &e); \
return; \
} G_STMT_END
@@ -2357,7 +2357,7 @@ static void
conn_requests_requestotron (TpBaseConnection *self,
GHashTable *requested_properties,
TpChannelManagerRequestMethod method,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TP_BASE_CONNECTION_ERROR_IF_NOT_CONNECTED (self, context);
@@ -2373,7 +2373,7 @@ static void
conn_requests_check_basic_properties (TpBaseConnection *self,
GHashTable *requested_properties,
TpChannelManagerRequestMethod method,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
/* Step 1:
* Check that ChannelType, TargetEntityType, TargetHandle, TargetID have
@@ -2452,7 +2452,7 @@ conn_requests_requestotron_validate_handle (TpBaseConnection *self,
TpEntityType target_entity_type,
TpHandle target_handle,
const gchar *target_id,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
/* Step 2: Validate the supplied set of Handle properties */
TpHandleRepoIface *handles = NULL;
@@ -2489,7 +2489,7 @@ conn_requests_requestotron_validate_handle (TpBaseConnection *self,
GError e = { TP_ERROR, TP_ERROR_NOT_AVAILABLE,
"Handle type not supported by this connection manager" };
- dbus_g_method_return_error (context, &e);
+ g_dbus_method_invocation_return_gerror (context, &e);
return;
}
@@ -2505,7 +2505,7 @@ conn_requests_requestotron_validate_handle (TpBaseConnection *self,
*/
error->domain = TP_ERROR;
error->code = TP_ERROR_INVALID_HANDLE;
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
g_error_free (error);
return;
}
@@ -2528,7 +2528,7 @@ conn_requests_requestotron_validate_handle (TpBaseConnection *self,
{
error->domain = TP_ERROR;
error->code = TP_ERROR_INVALID_HANDLE;
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
g_error_free (error);
return;
}
@@ -2575,7 +2575,7 @@ conn_requests_offer_request (TpBaseConnection *self,
const gchar *type,
TpEntityType target_entity_type,
TpHandle target_handle,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
/* Step 3: offer the incoming, vaguely sanitized request to the channel
* managers.
@@ -2623,7 +2623,7 @@ conn_requests_offer_request (TpBaseConnection *self,
static void
conn_requests_create_channel (TpSvcConnectionInterfaceRequests *svc,
GHashTable *requested_properties,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseConnection *self = TP_BASE_CONNECTION (svc);
@@ -2635,7 +2635,7 @@ conn_requests_create_channel (TpSvcConnectionInterfaceRequests *svc,
static void
conn_requests_ensure_channel (TpSvcConnectionInterfaceRequests *svc,
GHashTable *requested_properties,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseConnection *self = TP_BASE_CONNECTION (svc);
@@ -3016,7 +3016,7 @@ static void
contacts_get_contact_attributes_impl (TpSvcConnection *iface,
const GArray *handles,
const char **interfaces,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseConnection *conn = TP_BASE_CONNECTION (iface);
GHashTable *result;
@@ -3038,7 +3038,7 @@ typedef struct
{
TpBaseConnection *conn;
GStrv interfaces;
- DBusGMethodInvocation *context;
+ GDBusMethodInvocation *context;
} GetContactByIdData;
static void
@@ -3058,7 +3058,7 @@ ensure_handle_cb (GObject *source,
if (handle == 0)
{
- dbus_g_method_return_error (data->context, error);
+ g_dbus_method_invocation_return_gerror (data->context, error);
g_clear_error (&error);
goto out;
}
@@ -3089,7 +3089,7 @@ static void
contacts_get_contact_by_id_impl (TpSvcConnection *iface,
const gchar *id,
const gchar **interfaces,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseConnection *conn = TP_BASE_CONNECTION (iface);
TpHandleRepoIface *contact_repo = tp_base_connection_get_handles (conn,
@@ -331,7 +331,7 @@ struct _TpBaseConnectionPrivate
* so that we can use GArray's convenient auto-null-termination. */
GArray *interfaces;
- /* Array of DBusGMethodInvocation * representing Disconnect calls.
+ /* Array of GDBusMethodInvocation * representing Disconnect calls.
* If NULL and we are in a state != DISCONNECTED, then we have not started
* shutting down yet.
diff --git a/telepathy-glib/base-contact-list.c b/telepathy-glib/base-contact-list.c
index ad6b09db8..47e6d7506 100644
--- a/telepathy-glib/base-contact-list.c
+++ b/telepathy-glib/base-contact-list.c
@@ -278,7 +278,7 @@ struct _TpBaseContactListPrivate
/* owned gchar* => owned TpHandleSet */
GHashTable *groups;
/* DBusGMethodInvocation *s for calls to RequestBlockedContacts which are
* waiting for the contact list to (fail to) be downloaded.
*/
GQueue blocked_contact_requests;
@@ -530,11 +530,11 @@ tp_base_contact_list_fail_blocked_contact_requests (
TpBaseContactList *self,
const GError *error)
{
- DBusGMethodInvocation *context;
+ GDBusMethodInvocation *context;
while ((context = g_queue_pop_head (&self->priv->blocked_contact_requests))
!= NULL)
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
}
static void
@@ -996,7 +996,7 @@ tp_base_contact_list_set_list_received (TpBaseContactList *self)
self->priv->blocked_contact_requests.length > 0)
{
GHashTable *map = tp_handle_set_to_identifier_map (blocked);
- DBusGMethodInvocation *context;
+ GDBusMethodInvocation *context;
while ((context = g_queue_pop_head (
&self->priv->blocked_contact_requests)) != NULL)
@@ -3626,7 +3626,7 @@ static void
tp_base_contact_list_mixin_get_contact_list_attributes (
TpSvcConnectionInterfaceContactList1 *svc,
const gchar **interfaces,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseContactList *self = g_object_get_qdata ((GObject *) svc,
BASE_CONTACT_LIST);
@@ -3637,7 +3637,7 @@ tp_base_contact_list_mixin_get_contact_list_attributes (
if (tp_base_contact_list_get_state (self, &error)
!= TP_CONTACT_LIST_STATE_SUCCESS)
{
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
g_clear_error (&error);
}
else
@@ -3894,13 +3894,13 @@ tp_base_contact_list_check_group_change (TpBaseContactList *self,
/* Normally we'd use the return_from functions, but these methods all return
* void, and life's too short. */
static void
-tp_base_contact_list_mixin_return_void (DBusGMethodInvocation *context,
+tp_base_contact_list_mixin_return_void (GDBusMethodInvocation *context,
const GError *error)
{
if (error == NULL)
- dbus_g_method_return (context);
+ g_dbus_method_invocation_return_value (context, NULL);
else
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
}
static void
@@ -3921,7 +3921,7 @@ tp_base_contact_list_mixin_request_subscription (
TpSvcConnectionInterfaceContactList1 *svc,
const GArray *contacts,
const gchar *message,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseContactList *self = g_object_get_qdata ((GObject *) svc,
BASE_CONTACT_LIST);
@@ -3960,7 +3960,7 @@ static void
tp_base_contact_list_mixin_authorize_publication (
TpSvcConnectionInterfaceContactList1 *svc,
const GArray *contacts,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseContactList *self = g_object_get_qdata ((GObject *) svc,
BASE_CONTACT_LIST);
@@ -3999,7 +3999,7 @@ static void
tp_base_contact_list_mixin_remove_contacts (
TpSvcConnectionInterfaceContactList1 *svc,
const GArray *contacts,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseContactList *self = g_object_get_qdata ((GObject *) svc,
BASE_CONTACT_LIST);
@@ -4038,7 +4038,7 @@ static void
tp_base_contact_list_mixin_unsubscribe (
TpSvcConnectionInterfaceContactList1 *svc,
const GArray *contacts,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseContactList *self = g_object_get_qdata ((GObject *) svc,
BASE_CONTACT_LIST);
@@ -4077,7 +4077,7 @@ static void
tp_base_contact_list_mixin_unpublish (
TpSvcConnectionInterfaceContactList1 *svc,
const GArray *contacts,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseContactList *self = g_object_get_qdata ((GObject *) svc,
BASE_CONTACT_LIST);
@@ -4275,7 +4275,7 @@ tp_base_contact_list_mixin_download_cb (GObject *source,
static void
tp_base_contact_list_mixin_download (
TpSvcConnectionInterfaceContactList1 *svc,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseContactList *self = g_object_get_qdata ((GObject *) svc,
BASE_CONTACT_LIST);
@@ -4386,7 +4386,7 @@ tp_base_contact_list_mixin_set_contact_groups (
TpSvcConnectionInterfaceContactGroups1 *svc,
guint contact,
const gchar **groups,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseContactList *self = g_object_get_qdata ((GObject *) svc,
BASE_CONTACT_LIST);
@@ -4450,7 +4450,7 @@ tp_base_contact_list_mixin_set_group_members (
TpSvcConnectionInterfaceContactGroups1 *svc,
const gchar *group,
const GArray *contacts,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseContactList *self = g_object_get_qdata ((GObject *) svc,
BASE_CONTACT_LIST);
@@ -4491,7 +4491,7 @@ tp_base_contact_list_mixin_add_to_group (
TpSvcConnectionInterfaceContactGroups1 *svc,
const gchar *group,
const GArray *contacts,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseContactList *self = g_object_get_qdata ((GObject *) svc,
BASE_CONTACT_LIST);
@@ -4538,7 +4538,7 @@ tp_base_contact_list_mixin_remove_from_group (
TpSvcConnectionInterfaceContactGroups1 *svc,
const gchar *group,
const GArray *contacts,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseContactList *self = g_object_get_qdata ((GObject *) svc,
BASE_CONTACT_LIST);
@@ -4587,7 +4587,7 @@ static void
tp_base_contact_list_mixin_remove_group (
TpSvcConnectionInterfaceContactGroups1 *svc,
const gchar *group,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseContactList *self = g_object_get_qdata ((GObject *) svc,
BASE_CONTACT_LIST);
@@ -4633,7 +4633,7 @@ tp_base_contact_list_mixin_rename_group (
TpSvcConnectionInterfaceContactGroups1 *svc,
const gchar *before,
const gchar *after,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseContactList *self = g_object_get_qdata ((GObject *) svc,
BASE_CONTACT_LIST);
@@ -4764,14 +4764,14 @@ tp_base_contact_list_mixin_groups_iface_init (gpointer klass)
{ \
GError e = { TP_ERROR, TP_ERROR_NOT_IMPLEMENTED, \
"ContactBlocking is not supported on this connection" }; \
- dbus_g_method_return_error (context, &e); \
+ g_dbus_method_invocation_return_gerror (context, &e); \
return; \
}
static void
tp_base_contact_list_mixin_request_blocked_contacts (
TpSvcConnectionInterfaceContactBlocking1 *svc,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseContactList *self = g_object_get_qdata ((GObject *) svc,
BASE_CONTACT_LIST);
@@ -4787,7 +4787,7 @@ tp_base_contact_list_mixin_request_blocked_contacts (
case TP_CONTACT_LIST_STATE_FAILURE:
g_warn_if_fail (self->priv->failure != NULL);
- dbus_g_method_return_error (context, self->priv->failure);
+ g_dbus_method_invocation_return_gerror (context, self->priv->failure);
break;
case TP_CONTACT_LIST_STATE_SUCCESS:
@@ -4807,7 +4807,7 @@ tp_base_contact_list_mixin_request_blocked_contacts (
GError broken = { TP_ERROR, TP_ERROR_CONFUSED,
"My internal list of blocked contacts is inconsistent! "
"I apologise for any inconvenience caused." };
- dbus_g_method_return_error (context, &broken);
+ g_dbus_method_invocation_return_gerror (context, &broken);
g_return_if_reached ();
}
}
@@ -4820,7 +4820,7 @@ blocked_cb (
gpointer user_data)
{
TpBaseContactList *self = TP_BASE_CONTACT_LIST (source);
- DBusGMethodInvocation *context = user_data;
+ GDBusMethodInvocation *context = user_data;
GError *error = NULL;
if (tp_base_contact_list_block_contacts_with_abuse_finish (self, result,
@@ -4831,7 +4831,7 @@ blocked_cb (
}
else
{
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
g_clear_error (&error);
}
}
@@ -4841,7 +4841,7 @@ tp_base_contact_list_mixin_block_contacts (
TpSvcConnectionInterfaceContactBlocking1 *svc,
const GArray *contacts_arr,
gboolean report_abusive,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseContactList *self = g_object_get_qdata ((GObject *) svc,
BASE_CONTACT_LIST);
@@ -4863,7 +4863,7 @@ unblocked_cb (
gpointer user_data)
{
TpBaseContactList *self = TP_BASE_CONTACT_LIST (source);
- DBusGMethodInvocation *context = user_data;
+ GDBusMethodInvocation *context = user_data;
GError *error = NULL;
if (tp_base_contact_list_unblock_contacts_finish (self, result, &error))
@@ -4872,7 +4872,7 @@ unblocked_cb (
}
else
{
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
g_clear_error (&error);
}
}
@@ -4881,7 +4881,7 @@ static void
tp_base_contact_list_mixin_unblock_contacts (
TpSvcConnectionInterfaceContactBlocking1 *svc,
const GArray *contacts_arr,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseContactList *self = g_object_get_qdata ((GObject *) svc,
BASE_CONTACT_LIST);
@@ -278,7 +278,7 @@ struct _TpBaseContactListPrivate
/* owned gchar* => owned TpHandleSet */
GHashTable *groups;
- /* DBusGMethodInvocation *s for calls to RequestBlockedContacts which are
+ /* GDBusMethodInvocation *s for calls to RequestBlockedContacts which are
* waiting for the contact list to (fail to) be downloaded.
*/
diff --git a/telepathy-glib/base-room-config.c b/telepathy-glib/base-room-config.c
index f94888603..3e48ccc67 100644
--- a/telepathy-glib/base-room-config.c
+++ b/telepathy-glib/base-room-config.c
@@ -209,7 +209,7 @@ struct _TpBaseRoomConfigPrivate {
/* Details of a pending update, or both NULL if no call to
* UpdateConfiguration is in progress.
*/
- DBusGMethodInvocation *update_configuration_ctx;
+ GDBusMethodInvocation *update_configuration_ctx;
GHashTable *validated_properties;
};
@@ -898,7 +898,7 @@ update_cb (
}
else
{
- dbus_g_method_return_error (priv->update_configuration_ctx, error);
+ g_dbus_method_invocation_return_gerror (priv->update_configuration_ctx, error);
g_clear_error (&error);
}
@@ -922,7 +922,7 @@ static void
tp_base_room_config_update_configuration (
TpSvcChannelInterfaceRoomConfig1 *iface,
GHashTable *properties,
- DBusGMethodInvocation *context)
+ GDBusMethodInvocation *context)
{
TpBaseRoomConfig *self = find_myself ((GObject *) iface);
TpBaseChannel *channel = TP_BASE_CHANNEL (iface);
@@ -989,7 +989,7 @@ tp_base_room_config_update_configuration (
* mainly as a convenience to the subclass, which would probably like
* tp_base_room_config_get_channel() to work reliably.
*
* If the DBusGMethodInvocation kept the object alive, we wouldn't need this.
*/
g_object_ref (priv->channel);
/* This means the CM could modify validated_properties if it wanted. This is
@@ -1000,7 +1000,7 @@ tp_base_room_config_update_configuration (
return;
err:
- dbus_g_method_return_error (context, error);
+ g_dbus_method_invocation_return_gerror (context, error);
g_clear_error (&error);
}
@@ -989,7 +989,7 @@ tp_base_room_config_update_configuration (
* tp_base_room_config_get_channel() to work reliably.
*
- * If the DBusGMethodInvocation kept the object alive, we wouldn't need this.
+ * If the GDBusMethodInvocation kept the object alive, we wouldn't need this.
*/
g_object_ref (priv->channel);
diff --git a/telepathy-glib/handle-channel-context.c b/telepathy-glib/handle-channel-context.c
index c7e9d2356..1b3cc43ba 100644
--- a/telepathy-glib/handle-channel-context.c
+++ b/telepathy-glib/handle-channel-context.c
@@ -92,7 +92,7 @@ struct _TpHandleChannelContextPrivate
{
TpHandleChannelContextState state;
GSimpleAsyncResult *result;
- DBusGMethodInvocation *dbus_context;
+ GDBusMethodInvocation *dbus_context;
/* Number of calls we are waiting they return. Once they have all returned
* the context is considered as prepared */
@@ -398,14 +398,14 @@ tp_handle_channel_context_class_init (
/**
* TpHandleChannelContext:dbus-context: (skip)
*
* The #DBusGMethodInvocation representing the D-Bus context of the
* HandleChannels call.
* Can only be written during construction.
*
* Since: 0.11.6
*/
param_spec = g_param_spec_pointer ("dbus-context", "D-Bus context",
- "The DBusGMethodInvocation associated with the HandleChannels call",
+ "The GDBusMethodInvocation associated with the HandleChannels call",
G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS);
g_object_class_install_property (object_class, PROP_DBUS_CONTEXT,
param_spec);
@@ -434,7 +434,7 @@ TpHandleChannelContext * _tp_handle_channel_context_new (
GPtrArray *requests_satisfied,
guint64 user_action_time,
GVariant *handler_info,
- DBusGMethodInvocation *dbus_context)
+ GDBusMethodInvocation *dbus_context)
{
TpHandleChannelContext *ctx;
@@ -475,7 +475,7 @@ tp_handle_channel_context_accept (TpHandleChannelContext *self)
g_return_if_fail (self->priv->dbus_context != NULL);
self->priv->state = TP_HANDLE_CHANNEL_CONTEXT_STATE_DONE;
- dbus_g_method_return (self->priv->dbus_context);
+ g_dbus_method_invocation_return_value (self->priv->dbus_context, NULL);
self->priv->dbus_context = NULL;
@@ -501,7 +501,7 @@ tp_handle_channel_context_fail (TpHandleChannelContext *self,
g_return_if_fail (self->priv->dbus_context != NULL);
self->priv->state = TP_HANDLE_CHANNEL_CONTEXT_STATE_FAILED;
- dbus_g_method_return_error (self->priv->dbus_context, error);
+ g_dbus_method_invocation_return_gerror (self->priv->dbus_context, error);
self->priv->dbus_context = NULL;
}
@@ -398,14 +398,14 @@ tp_handle_channel_context_class_init (
* TpHandleChannelContext:dbus-context: (skip)
*
- * The #DBusGMethodInvocation representing the D-Bus context of the
+ * The #GDBusMethodInvocation representing the D-Bus context of the
* HandleChannels call.
* Can only be written during construction.
diff --git a/telepathy-glib/observe-channel-context.c b/telepathy-glib/observe-channel-context.c
index e5efa57c5..68a952ace 100644
--- a/telepathy-glib/observe-channel-context.c
+++ b/telepathy-glib/observe-channel-context.c
@@ -81,7 +81,7 @@ struct _TpObserveChannelContextPrivate
{
TpObserveChannelContextState state;
GSimpleAsyncResult *result;
- DBusGMethodInvocation *dbus_context;
+ GDBusMethodInvocation *dbus_context;
/* Number of calls we are waiting they return. Once they have all returned
* the context is considered as prepared */
@@ -358,14 +358,14 @@ tp_observe_channel_context_class_init (TpObserveChannelContextClass *cls)
/**
* TpObserveChannelContext:dbus-context: (skip)
*
* The #DBusGMethodInvocation representing the D-Bus context of the
* ObserveChannels call.
* Can only be written during construction.
*
* Since: 0.11.5
*/
param_spec = g_param_spec_pointer ("dbus-context", "D-Bus context",
- "The DBusGMethodInvocation associated with the ObserveChannels call",
+ "The GDBusMethodInvocation associated with the ObserveChannels call",
G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS);
g_object_class_install_property (object_class, PROP_DBUS_CONTEXT,
param_spec);
@@ -399,7 +399,7 @@ _tp_observe_channel_context_new (
TpChannelDispatchOperation *dispatch_operation,
GPtrArray *requests,
GHashTable *observer_info,
- DBusGMethodInvocation *dbus_context)
+ GDBusMethodInvocation *dbus_context)
{
return g_object_new (TP_TYPE_OBSERVE_CHANNELS_CONTEXT,
"account", account,
@@ -429,7 +429,7 @@ tp_observe_channel_context_accept (TpObserveChannelContext *self)
g_return_if_fail (self->priv->dbus_context != NULL);
self->priv->state = TP_OBSERVE_CHANNEL_CONTEXT_STATE_DONE;
- dbus_g_method_return (self->priv->dbus_context);
+ g_dbus_method_invocation_return_value (self->priv->dbus_context, NULL);
self->priv->dbus_context = NULL;
}
@@ -452,7 +452,7 @@ tp_observe_channel_context_fail (TpObserveChannelContext *self,
g_return_if_fail (self->priv->dbus_context != NULL);
self->priv->state = TP_OBSERVE_CHANNEL_CONTEXT_STATE_FAILED;
- dbus_g_method_return_error (self->priv->dbus_context, error);
+ g_dbus_method_invocation_return_gerror (self->priv->dbus_context, error);
self->priv->dbus_context = NULL;
}
@@ -358,14 +358,14 @@ tp_observe_channel_context_class_init (TpObserveChannelContextClass *cls)
* TpObserveChannelContext:dbus-context: (skip)
*
- * The #DBusGMethodInvocation representing the D-Bus context of the
+ * The #GDBusMethodInvocation representing the D-Bus context of the
* ObserveChannels call.
* Can only be written during construction.